@@ -32,6 +32,7 @@
 #include "src/svnqt/url.hpp"
 #include "helpers/ktranslateurl.h"
 #include "helpers/sshagent.h"
+#include "svnfrontend/database/dboverview.h"
 
 #include <kcomponentdata.h>
 #include <kaction.h>
@@ -224,7 +225,7 @@ void kdesvnpart::setupActions()
         connect(t,SIGNAL(triggered(bool) ), SLOT(showAboutApplication()));
         actionCollection()->addAction("help_about_kdesvnpart",t);
 
-        t = new KAction(KIcon("help"),i18n("Kdesvn Handbook"), this);
+        t = new KAction(KIcon("help-contents"),i18n("Kdesvn Handbook"), this);
         connect(t,SIGNAL(triggered(bool) ), SLOT(appHelpActivated()));
         actionCollection()->addAction("help_kdesvn",t);
 
@@ -347,7 +348,7 @@ void kdesvnpart::showAboutApplication()
  */
 void kdesvnpart::appHelpActivated()
 {
-    KToolInvocation::invokeHelp(QString::null, "kdesvn");
+    KToolInvocation::invokeHelp(QString(), "kdesvn");
 }
 
 
@@ -366,7 +367,7 @@ void kdesvnpart::slotShowSettings()
 
     dialog->setHelp("setup","kdesvn");
     dialog->addPage(new DisplaySettings_impl(0),
-        i18n("General"),"configure",i18n("General"),true);
+        i18n("General"),"configure",i18n("General Settings"),true);
     dialog->addPage(new SubversionSettings_impl(0),
         i18n("Subversion"),"kdesvn",i18n("Subversion Settings"),true);
     dialog->addPage(new DiffMergeSettings_impl(0),
@@ -407,4 +408,12 @@ void kdesvnpart::slotSettingsChanged(const QString&)
     emit settingsChanged();
 }
 
+void kdesvnpart::showDbStatus()
+{
+    if (m_view) {
+        m_view->stopCacheThreads();
+        DbOverview::showDbOverview();
+    }
+}
+
 #include "kdesvn_part.moc"
