@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
- *   rajko.albrecht@tecways.com                                            *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht  ral@alwins-world.de        *
+ *   http://kdesvn.alwins-world.de/                                        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include "kdesvn-config.h"
@@ -31,6 +31,7 @@
 #include "src/svnqt/context_listener.hpp"
 #include "src/svnqt/url.hpp"
 #include "src/svnqt/svnqttypes.hpp"
+#include "src/svnqt/client_parameter.hpp"
 #include "helpers/ktranslateurl.h"
 #include "kdesvndadaptor.h"
 
@@ -122,16 +123,26 @@ kdesvnd::~kdesvnd()
     delete m_Listener;
 }
 
+QStringList kdesvnd::getTopLevelActionMenu(const KUrl::List&list)
+{
+    return getActionMenu(list,true);
+}
+
 QStringList kdesvnd::getActionMenu (const KUrl::List& list)
+{
+    return getActionMenu(list,false);
+}
+
+QStringList kdesvnd::getActionMenu(const KUrl::List& list,bool toplevel)
 {
     QStringList result;
     Kdesvnsettings::self()->readConfig();
-    if (Kdesvnsettings::no_konqueror_contextmenu()||list.count()==0) {
+    if (Kdesvnsettings::no_konqueror_contextmenu()||list.count()==0 ||
+        (toplevel&&Kdesvnsettings::no_konqueror_toplevelmenu()) ) {
         return result;
     }
     QString base;
 
-
     bool parentIsWc = false;
     bool itemIsWc = isWorkingCopy(list[0],base);
     bool itemIsRepository = false;
@@ -158,41 +169,41 @@ QStringList kdesvnd::getActionMenu (const KUrl::List& list)
 
     if (!parentIsWc && !itemIsWc) {
         if (itemIsRepository) {
-            result << "Log"
-                    << "Info";
-            if (isRepository(list[0].upUrl())) {
-                result << "Blame"
-                        << "Rename";
+            result << "Log";
+            if (!toplevel) {
+                result << "Info";
+                if (isRepository(list[0].upUrl())) {
+                    result << "Blame"
+                            << "Rename";
+                }
+                result << "Tree";
             }
-            result << "Tree";
         }
-        return result;
+    } else if (!toplevel) {
+        if (!itemIsWc) {
+            result << "Add";
+            return result;
+        }
+
+        result << "Log"
+            << "Tree"
+            << "Info"
+            << "Diff"
+            << "Rename"
+            << "Revert";
+
+        KUrl url = helpers::KTranslateUrl::translateSystemUrl(list[0]);
+
+        QFileInfo f(url.path());
+        if (f.isFile()) {
+            result << "Blame";
+        }
+
+        if (f.isDir()) {
+            result << "Addnew";
+            result << "Switch";
+        }
     }
-
-    if (!itemIsWc) {
-        result << "Add";
-        return result;
-    }
-
-    result << "Log"
-        << "Tree"
-        << "Info"
-        << "Diff"
-        << "Rename"
-        << "Revert";
-
-    KUrl url = helpers::KTranslateUrl::translateSystemUrl(list[0]);
-
-    QFileInfo f(url.path());
-    if (f.isFile()) {
-        result << "Blame";
-    }
-
-    if (f.isDir()) {
-        result << "Addnew";
-        result << "Switch";
-    }
-
     return result;
 }
 
@@ -202,6 +213,19 @@ QStringList kdesvnd::getSingleActionMenu(const QString& what)
     return getActionMenu(l);
 }
 
+QStringList kdesvnd::get_saved_login(const QString&realm,const QString&user)
+{
+    Q_UNUSED(user);
+    QString username;
+    QString password;
+    PwStorage::self()->getLogin(realm,username,password);
+    QStringList res;
+    res.append(username);
+    res.append(password);
+    return res;
+
+}
+
 QStringList kdesvnd::get_login(const QString&realm,const QString&user)
 {
     AuthDialogImpl auth(realm,user);
@@ -238,12 +262,21 @@ int kdesvnd::get_sslaccept(const QString& hostname,const QString& fingerprint,co
     return 1;
 }
 
+QString kdesvnd::load_sslclientcertpw(const QString& realm)
+{
+    QString password;
+    if (!PwStorage::self()->getCertPw(realm,password)) {
+        return QString();
+    }
+    return password;
+}
+
 QStringList kdesvnd::get_sslclientcertpw(const QString& realm)
 {
     QStringList resList;
     KPasswordDialog dlg(0,KPasswordDialog::DomainReadOnly|KPasswordDialog::ShowKeepPassword);
     dlg.setDomain(realm);
-    dlg.setCaption(i18n("Enter password for realm %1").arg(realm));
+    dlg.setCaption(i18n("Enter password for realm %1",realm));
     dlg.setKeepPassword(true);
     if (dlg.exec()!=KPasswordDialog::Accepted) {
         return resList;
@@ -260,7 +293,7 @@ QStringList kdesvnd::get_sslclientcertpw(const QString& realm)
 QString kdesvnd::get_sslclientcertfile()
 {
     QString afile = KFileDialog::getOpenFileName(KUrl(),
-        QString::null,
+        QString(),
         0,
         i18n("Open a file with a #PKCS12 certificate"));
     return afile;
@@ -278,47 +311,25 @@ QStringList kdesvnd::get_logmsg()
     return res;
 }
 
-QStringList kdesvnd::get_logmsg(const QDBusVariant&_in)
-{
-    QStringList res;
-    if (_in.variant().type()!=QVariant::Map) {
-        return res;
-    }
-    QMap<QString,QVariant> v = _in.variant().toMap();
-    QMap<QString,QString> list;
-    QMap<QString,QVariant>::const_iterator _it=v.begin();
-    for(;_it!=v.end();++_it) {
-        list[_it.key()]=_it.value().toString();
-    }
-
-    bool ok;
-    QString logMessage = Commitmsg_impl::getLogmessage(list,&ok,0,0,0);
-    if (!ok) {
-        return res;
-    }
-    res.append(logMessage);
-    return res;
-}
-
 QString kdesvnd::cleanUrl(const KUrl&url)
 {
     QString cleanpath = url.path();
-    while (cleanpath.endsWith("/")) {
+    while (cleanpath.endsWith('/')) {
         cleanpath.truncate(cleanpath.length()-1);
     }
     return cleanpath;
 }
 
-/* just simple name check of course - no network acess! */
+/* just simple name check of course - no network access! */
 bool kdesvnd::isRepository(const KUrl&url)
 {
     QString proto = svn::Url::transformProtokoll(url.protocol());
     if (proto=="file") {
         // local access - may a repository
-        svn::Revision where = svn::Revision::HEAD;
         svn::StatusEntries dlist;
+        svn::StatusParameter params("file://"+cleanUrl(url));
         try {
-            m_Listener->m_Svnclient->status("file://"+cleanUrl(url),svn::DepthEmpty,false,false,false,where);
+            m_Listener->m_Svnclient->status(params.depth(svn::DepthEmpty).all(false).update(false).noIgnore(false).revision(svn::Revision::HEAD));
         } catch (const svn::ClientException&e) {
             kDebug(9510)<< e.msg()<<endl;
             return false;
