@@ -21,12 +21,18 @@
 #include "kiosvn.h"
 #include "kiolistener.h"
 
+#include <QFile>
+#include <QTemporaryFile>
+
 #include "src/svnqt/svnqttypes.hpp"
 #include "src/svnqt/dirent.hpp"
 #include "src/svnqt/url.hpp"
 #include "src/svnqt/status.hpp"
 #include "src/svnqt/targets.hpp"
 #include "src/svnqt/info_entry.hpp"
+#include "src/svnqt/client_parameter.hpp"
+#include "src/svnqt/client_commit_parameter.hpp"
+#include "src/svnqt/shared_pointer.hpp"
 #include "src/settings/kdesvnsettings.h"
 #include "src/helpers/sub2qt.h"
 #include "src/helpers/sshagent.h"
@@ -48,16 +54,11 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kurl.h>
-#include <ktempdir.h>
+#include <KTempDir>
+#include <KTemporaryFile>
 #include <kmimetype.h>
 #include <krun.h>
-
-#include <stdlib.h>
-#include <math.h>
-#include <unistd.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
+#include <kio/slaveinterface.h>
 
 namespace KIO
 {
@@ -73,11 +74,11 @@ public:
     KioListener m_Listener;
     bool first_done;
     bool dispProgress;
+    bool dispWritten;
     svn::ContextP m_CurrentContext;
     svn::Client* m_Svnclient;
-
     svn::Revision urlToRev(const KUrl&);
-
+    QTime _last;
 };
 
 KioSvnData::KioSvnData(kio_svnProtocol*par)
@@ -86,6 +87,8 @@ KioSvnData::KioSvnData(kio_svnProtocol*par)
     m_Svnclient=svn::Client::getobject(0,0);
     m_CurrentContext = 0;
     dispProgress = false;
+    dispWritten = false;
+    _last = QTime::currentTime();
     reInitClient();
 }
 
@@ -256,7 +259,6 @@ void kio_svnProtocol::stat(const KUrl& url)
 
 void kio_svnProtocol::get(const KUrl& url)
 {
-    kDebug(9510)<<"kio_svn::get "<< url << endl;
     if (m_pData->m_Listener.contextCancel()) {
         finished();
         return;
@@ -267,14 +269,18 @@ void kio_svnProtocol::get(const KUrl& url)
     }
     KioByteStream dstream(this,url.fileName());
     try {
-        m_pData->m_Svnclient->cat(dstream,makeSvnUrl(url),rev,rev);
+        QString _url = makeSvnUrl(url);
+        svn::InfoEntries e;
+        e = m_pData->m_Svnclient->info(_url,svn::DepthEmpty,rev,rev);
+        if (e.size()>0) {
+            totalSize(e[0].size());
+        }
+        m_pData->m_Svnclient->cat(dstream,_url,rev,rev);
     } catch (const svn::ClientException&e) {
         QString ex = e.msg();
-        kDebug(9510)<<ex<<endl;
         error( KIO::ERR_SLAVE_DEFINED,"Subversion error "+ex);
         return;
     }
-    totalSize(dstream.written());
     data(QByteArray()); // empty array means we're done sending the data
     finished();
 }
@@ -286,6 +292,11 @@ void kio_svnProtocol::mkdir(const KUrl &url, int)
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
+    if (rev != svn::Revision::HEAD) {
+        error(KIO::ERR_SLAVE_DEFINED,i18n("Can only write on head revision!"));
+        return;
+    }
+    m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
         svn::Path p(makeSvnUrl(url));
         m_pData->m_Svnclient->mkdir(p,getDefaultLog());
@@ -321,7 +332,7 @@ void kio_svnProtocol::rename(const KUrl&src,const KUrl&target,KIO::JobFlags flag
     QString msg;
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
-        m_pData->m_Svnclient->move(makeSvnUrl(src),makeSvnUrl(target),false);
+        m_pData->m_Svnclient->move(svn::CopyParameter(makeSvnUrl(src),makeSvnUrl(target)).force(false));
     } catch (const svn::ClientException&e) {
         if (e.apr_err()==SVN_ERR_ENTRY_EXISTS) {
             error(KIO::ERR_DIR_ALREADY_EXIST,e.msg());
@@ -335,6 +346,113 @@ void kio_svnProtocol::rename(const KUrl&src,const KUrl&target,KIO::JobFlags flag
     finished();
 }
 
+void kio_svnProtocol::put(const KUrl&url,int permissions,KIO::JobFlags flags)
+{
+    Q_UNUSED(permissions);
+    svn::Revision rev = m_pData->urlToRev(url);
+    if (rev == svn::Revision::UNDEFINED) {
+        rev = svn::Revision::HEAD;
+    }
+    if (rev != svn::Revision::HEAD) {
+        error(KIO::ERR_SLAVE_DEFINED,i18n("Can only write on head revision!"));
+        return;
+    }
+    svn::Revision peg = rev;
+    svn::InfoEntries e;
+    bool exists = true;
+    try {
+         e = m_pData->m_Svnclient->info(makeSvnUrl(url),svn::DepthEmpty,rev,peg);
+    } catch  (const svn::ClientException&e) {
+        if (e.apr_err()==SVN_ERR_ENTRY_NOT_FOUND || e.apr_err()==SVN_ERR_RA_ILLEGAL_URL) {
+            exists = false;
+        } else {
+            error(KIO::ERR_SLAVE_DEFINED,e.msg());
+            return;
+        }
+    }
+    svn::SharedPointer<QFile> tmpfile = 0;
+    svn::SharedPointer<KTempDir> _codir = 0;
+    if (exists) {
+        if (flags & KIO::Overwrite) {
+            if (!supportOverwrite()) {
+                error(KIO::ERR_SLAVE_DEFINED,i18n("Overwriting existing items is disabled in settings."));
+                return;
+            }
+            _codir = new KTempDir;
+            _codir->setAutoRemove(true);
+            svn::Path path = makeSvnUrl(url.url());
+            path.removeLast();
+            try {
+                svn::CheckoutParameter params;
+                params.moduleName(path).destination(svn::Path(_codir->name())).revision(rev).peg(peg).depth(svn::DepthFiles);
+                m_pData->m_Svnclient->checkout(params);
+            } catch (const svn::ClientException&e) {
+                error(KIO::ERR_SLAVE_DEFINED,e.msg());
+                return;
+            }
+            tmpfile = new QFile(_codir->name()+url.fileName());
+            tmpfile->open(QIODevice::ReadWrite|QIODevice::Truncate);
+        } else {
+            error(KIO::ERR_FILE_ALREADY_EXIST,i18n("Could not write to existing item."));
+            return;
+        }
+    } else {
+        KTemporaryFile* _tmpfile = new KTemporaryFile();
+        if (!_tmpfile->open()) {
+            error(KIO::ERR_SLAVE_DEFINED,i18n("Could not open temporary file"));
+            delete _tmpfile;
+            return;
+        }
+        tmpfile = _tmpfile;
+    }
+    int result = 0;
+    QByteArray buffer;
+    KIO::fileoffset_t processed_size = 0;
+    do {
+        dataReq();
+        result = readData(buffer);
+        if (result>0) {
+            tmpfile->write(buffer);
+            processed_size += result;
+            processedSize(processed_size);
+        }
+        buffer.clear();
+    } while (result>0);
+
+    tmpfile->flush();
+
+
+    if (result!=0) {
+        error(KIO::ERR_ABORTED,i18n("Could not retrieve data for write."));
+        return;
+    }
+
+    totalSize(processed_size);
+    written (0);
+    m_pData->dispWritten = true;
+    bool err = false;
+    if (exists) {
+        svn::CommitParameter commit_parameters;
+        commit_parameters.targets(svn::Targets(tmpfile->fileName())).message(getDefaultLog()).depth(svn::DepthEmpty).keepLocks(false);
+        try {
+            m_pData->m_Svnclient->commit(commit_parameters);
+        } catch (const svn::ClientException&e) {
+            error(KIO::ERR_SLAVE_DEFINED,e.msg());
+            err = true;
+        }
+    } else  {
+        try {
+            m_pData->m_Svnclient->import(tmpfile->fileName(),makeSvnUrl(url),getDefaultLog(),svn::DepthEmpty,false,false);
+        } catch  (const svn::ClientException&e) {
+            QString ex = e.msg();
+            error(KIO::ERR_SLAVE_DEFINED,e.msg());
+            err = true;
+        }
+    }
+    m_pData->dispWritten = false;
+    if (!err) finished();
+}
+
 void kio_svnProtocol::copy(const KUrl&src,const KUrl&dest,int permissions,KIO::JobFlags flags)
 {
     Q_UNUSED(permissions);
@@ -373,6 +491,10 @@ void kio_svnProtocol::del(const KUrl&src,bool isfile)
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
+    if (rev != svn::Revision::HEAD) {
+        error(KIO::ERR_SLAVE_DEFINED,i18n("Can only write on head revision!"));
+        return;
+    }
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
         svn::Targets target(makeSvnUrl(src));
@@ -427,7 +549,7 @@ QString kio_svnProtocol::makeSvnUrl(const KUrl&url,bool check_Wc)
     QStringList s = res.split("://");
     QString base = url.path();
     QString host = url.host();
-    QString user = (url.hasUser()?url.user()+(url.hasPass()?":"+url.pass():""):"");
+    QString user = (url.hasUser()?url.user()+(url.hasPass()?':'+url.pass():""):"");
     if (host.isEmpty()) {
         res=proto+"://"+base;
     } else {
@@ -570,7 +692,7 @@ void kio_svnProtocol::special(const QByteArray& data)
             KUrl::List list;
             stream >> list;
             kDebug(0) << "kio_svnProtocol MKDIR" << endl;
-            mkdir(list,0);
+            this->mkdir(list,0);
             break;
         }
         case SVN_RESOLVE:
@@ -638,11 +760,10 @@ void kio_svnProtocol::update(const KUrl&url,int revnumber,const QString&revkind)
 
 void kio_svnProtocol::status(const KUrl&wc,bool cR,bool rec)
 {
-    svn::Revision where = svn::Revision::UNDEFINED;
     svn::StatusEntries dlist;
+    svn::StatusParameter params(wc.path());
     try {
-        //                                            rec all  up     noign
-        dlist = m_pData->m_Svnclient->status(wc.path(),rec?svn::DepthInfinity:svn::DepthEmpty,false,cR,false,where);
+        dlist = m_pData->m_Svnclient->status(params.depth(rec?svn::DepthInfinity:svn::DepthEmpty).all(false).update(cR).noIgnore(false).revision(svn::Revision::UNDEFINED));
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
@@ -698,15 +819,18 @@ void kio_svnProtocol::commit(const KUrl::List&url)
         targets.push_back(svn::Path(url[j].path()));
     }
     svn::Revision nnum=svn::Revision::UNDEFINED;
+    svn::CommitParameter commit_parameters;
+    commit_parameters.targets(svn::Targets(targets)).message(msg).depth(svn::DepthInfinity).keepLocks(false);
+
     try {
-        nnum = m_pData->m_Svnclient->commit(svn::Targets(targets),msg,svn::DepthInfinity,false);
+        nnum = m_pData->m_Svnclient->commit(commit_parameters);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
     for (long j=0;j<url.count();++j) {
         QString userstring;
         if (nnum!=svn::Revision::UNDEFINED) {
-            userstring = i18n( "Committed revision %1." ).arg(nnum.toString());
+            userstring = i18n( "Committed revision %1.",nnum.toString());
         } else {
             userstring = i18n ( "Nothing to commit." );
         }
@@ -725,11 +849,10 @@ void kio_svnProtocol::commit(const KUrl::List&url)
 void kio_svnProtocol::checkout(const KUrl&src,const KUrl&target,const int rev, const QString&revstring)
 {
     svn::Revision where(rev,revstring);
-    svn::Revision peg = svn::Revision::UNDEFINED;
-    svn::Path _target(target.path());
     try {
-        KUrl _src = makeSvnUrl(src);
-        m_pData->m_Svnclient->checkout(_src.url(),_target,where,peg,svn::DepthInfinity,false,false);
+        svn::CheckoutParameter params;
+        params.moduleName(makeSvnUrl(src)).destination(target.path()).revision(where).peg(svn::Revision::UNDEFINED).depth(svn::DepthInfinity);
+        m_pData->m_Svnclient->checkout(params);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
@@ -739,45 +862,49 @@ void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int reven
 {
     svn::Revision start(revstart,revstringstart);
     svn::Revision end(revend,revstringend);
-    svn::LogEntriesPtr logs;
+    svn::LogParameter params;
+    params.revisionRange(start,end).peg(svn::Revision::UNDEFINED).limit(0).discoverChangedPathes(true).strictNodeHistory(true);
 
     for (long j = 0; j<urls.count();++j) {
-        logs = 0;
+        svn::LogEntriesMap logs;
         try {
-            logs = m_pData->m_Svnclient->log(makeSvnUrl(urls[j]),start,end,svn::Revision::UNDEFINED,true,true,0);
+            m_pData->m_Svnclient->log(params.targets(makeSvnUrl(urls[j])),logs);
         } catch (const svn::ClientException&e) {
             error(KIO::ERR_SLAVE_DEFINED,e.msg());
             break;
         }
-        if (!logs) {
+        if (logs.size()==0) {
             setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10,'0')+"path",urls[j].path());
             setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10,'0')+"string",
                 i18n("Empty logs"));
             m_pData->m_Listener.incCounter();
             continue;
         }
-        for (long i = 0; i < logs->count();++i) {
+
+        svn::LogEntriesMap::const_iterator it = logs.begin();
+        for (;it!=logs.end();++it) {
             setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "path",urls[j].path());
             setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "rev",
-                QString::number( (*logs)[i].revision));
+                QString::number( (*it).revision));
             setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+"author",
-                (*logs)[i].author);
+                (*it).author);
             setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+"logmessage",
-                (*logs)[i].message);
+                (*it).message);
             m_pData->m_Listener.incCounter();
-            for (long z = 0; z<(*logs)[i].changedPaths.count();++z) {
+            for (long z = 0; z<(*it).changedPaths.count();++z) {
                 setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "rev",
-                    QString::number( (*logs)[i].revision));
+                    QString::number( (*it).revision));
                 setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "path",urls[j].path());
                 setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedpath",
-                    (*logs)[i].changedPaths[z].path);
+                    (*it).changedPaths[z].path);
                 setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedaction",
-                    QChar((*logs)[i].changedPaths[z].action));
+                    QChar((*it).changedPaths[z].action));
                 setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedcopyfrompath",
-                    (*logs)[i].changedPaths[z].copyFromPath);
+                    (*it).changedPaths[z].copyFromPath);
                 setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedcopyfromrevision",
-                    QString::number((*logs)[i].changedPaths[z].copyFromRevision));
+                    QString::number((*it).changedPaths[z].copyFromRevision));
                 m_pData->m_Listener.incCounter();
+
             }
         }
     }
@@ -821,10 +948,15 @@ void kio_svnProtocol::diff(const KUrl&uri1,const KUrl&uri2,int rnum1,const QStri
         kDebug(9510) << "kio_ksvn::diff : " << u1 << " at revision " << r1.toString() << " with "
             << u2 << " at revision " << r2.toString()
             << endl ;
+        svn::DiffParameter _opts;
+        // no peg revision required
+        _opts.path1(u1).path2(u2).tmpPath(tdir.name()).
+            rev1(r1).rev2(r2).
+            ignoreContentType(false).extra(svn::StringArray()).depth(rec?svn::DepthInfinity:svn::DepthEmpty).ignoreAncestry(false).noDiffDeleted(false).
+            relativeTo(svn::Path((u1==u2?u1:""))).changeList(svn::StringArray());
 
         tdir.setAutoRemove(true);
-            ex = m_pData->m_Svnclient->diff(svn::Path(tdir.name()),
-                                            u1,u2,svn::Path(),r1, r2,rec?svn::DepthInfinity:svn::DepthEmpty,false,false,false);
+        ex = m_pData->m_Svnclient->diff(_opts);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
@@ -842,7 +974,7 @@ void kio_svnProtocol::import(const KUrl& repos, const KUrl& wc)
     try {
         QString target = makeSvnUrl(repos);
         QString path = wc.path();
-        m_pData->m_Svnclient->import(svn::Path(path),target,QString::null,svn::DepthInfinity,false,false);
+        m_pData->m_Svnclient->import(svn::Path(path),target,QString(),svn::DepthInfinity,false,false);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
@@ -907,25 +1039,37 @@ void kio_svnProtocol::streamPushData(QByteArray array)
     data(array);
 }
 
-void kio_svnProtocol::contextProgress(long long int current, long long int)
+void kio_svnProtocol::contextProgress(long long int current, long long int max)
 {
-    if (m_pData->dispProgress) {
-        processedSize(current);
+    if (max > -1) {
+        totalSize(KIO::filesize_t(max));
+    }
+
+    if (m_pData->dispProgress||m_pData->dispWritten) {
+        QTime now = QTime::currentTime();
+        if (m_pData->_last.msecsTo(now)>=90) {
+            if (m_pData->dispProgress) {
+                processedSize(KIO::filesize_t(current));
+            } else {
+                written(current);
+            }
+            m_pData->_last = now;
+        }
     }
 }
 
-void kio_svnProtocol::streamTotalSizeNull()
+bool kio_svnProtocol::supportOverwrite()
 {
-    totalSize(0);
+    Kdesvnsettings::self()->readConfig();
+    return Kdesvnsettings::kio_can_overwrite();
 }
 
-
 /*!
     \fn kio_svnProtocol::getDefaultLog()
  */
 QString kio_svnProtocol::getDefaultLog()
 {
-    QString res = QString::null;
+    QString res;
     Kdesvnsettings::self()->readConfig();
     if (Kdesvnsettings::kio_use_standard_logmsg()) {
         res = Kdesvnsettings::kio_standard_logmsg();
