@@ -54,6 +54,7 @@ public:
     virtual void get(const KUrl& url);
     virtual void mkdir (const KUrl &url, int permissions);
     virtual void mkdir (const KUrl::List &urls, int permissions);
+    virtual void put(const KUrl&url,int permissions,KIO::JobFlags flags);
     virtual void rename(const KUrl&src,const KUrl&target,KIO::JobFlags flags);
     virtual void del(const KUrl&url,bool isfile);
     virtual void copy(const KUrl&src,const KUrl&dest,int permissions,KIO::JobFlags flags);
@@ -101,7 +102,6 @@ public:
     virtual void streamWritten(const KIO::filesize_t current);
     virtual void streamPushData(QByteArray);
     virtual void streamSendMime(KMimeType::Ptr mt);
-    virtual void streamTotalSizeNull();
 
     virtual void listSendDirEntry(const svn::DirEntry&);
 
@@ -118,6 +118,7 @@ private:
     bool getLogMsg(QString&);
 protected:
     QString getDefaultLog();
+    bool supportOverwrite();
 };
 
 }
