@@ -75,14 +75,17 @@ PwStorageData::cache_type*PwStorageData::getLoginCache()
 KWallet::Wallet*PwStorageData::getWallet()
 {
     static bool walletOpenFailed = false;
-    if (m_Wallet && m_Wallet->isOpen()) {
+    if ( (m_Wallet && m_Wallet->isOpen()) || !qApp) {
         return m_Wallet;
     }
-
     if (KWallet::Wallet::isEnabled()) {
         WId window = 0;
-        if ( qApp->activeWindow() ) {
-            window = qApp->activeWindow()->winId();
+        if (qApp) {
+            if (qApp->activeModalWidget()) {
+                window = qApp->activeModalWidget()->winId();
+            } else if (qApp->activeWindow()) {
+                window = qApp->activeWindow()->winId();
+            }
         }
         delete m_Wallet;
         m_Wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(),window);
