@@ -20,46 +20,42 @@
 #ifndef BLAMEDISPLAY_IMPL_H
 #define BLAMEDISPLAY_IMPL_H
 
-#include "blamedisplay.h"
+#include "ui_blamedisplay.h"
 #include "src/svnqt/client.hpp"
 
 class BlameDisplayData;
 class SimpleLogCb;
-class BlameDisplayItem;
-class KListViewSearchLineWidget;
+class BlameTreeItem;
+class QAction;
 
-class BlameDisplay_impl:public BlameDisplay
+class BlameDisplay_impl:public QWidget,public Ui::BlameDisplay
 {
     Q_OBJECT
 public:
-    BlameDisplay_impl(const QString&,const svn::AnnotatedFile&,QWidget*parent=0,const char*name=0);
-    BlameDisplay_impl(QWidget*parent=0,const char*name=0);
+    BlameDisplay_impl(QWidget*parent=0);
     virtual ~BlameDisplay_impl();
 
     virtual void setContent(const QString&,const svn::AnnotatedFile&);
     virtual void setCb(SimpleLogCb*);
 
     const QColor rev2color(svn_revnum_t)const;
-
-    static void displayBlame(SimpleLogCb*,const QString&,const svn::AnnotatedFile&,QWidget*parent=0,const char*name=0);
+    static void displayBlame(SimpleLogCb*,const QString&,const svn::AnnotatedFile&,QWidget*parent=0);
 
 public slots:
     virtual void slotGoLine();
     virtual void slotShowCurrentCommit();
 
 protected slots:
-    virtual void slotContextMenuRequested(KListView*,QListViewItem*, const QPoint&);
-    virtual void slotSelectionChanged();
+    virtual void slotCurrentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*);
     virtual void slotTextCodecChanged(const QString&);
 
 protected:
-    virtual void showCommit(BlameDisplayItem*);
-    KListViewSearchLineWidget* m_SearchWidget;
+    virtual void showCommit(BlameTreeItem*);
 
 private:
     BlameDisplayData*m_Data;
 protected slots:
-    virtual void slotItemDoubleClicked(QListViewItem*);
+    virtual void slotItemDoubleClicked(QTreeWidgetItem*,int);
 };
 
 #endif
