@@ -30,6 +30,7 @@
 #include <kpassworddialog.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
+#include <kmessagebox.h>
 
 #include <QTextStream>
 #include <qthread.h>
@@ -72,14 +73,14 @@ const QString CContextListener::action_strings[]={
     I18N_NOOP("Update"), //svn_wc_notify_update_update
     I18N_NOOP("Update complete"),
     I18N_NOOP("Update external module"),
-    QString::null, // status completed - will not send is just noisy
+    QString(), // status completed - will not send is just noisy
     I18N_NOOP("Status on external"), //svn_wc_notify_status_external
     I18N_NOOP("Commit Modified"),
     I18N_NOOP("Commit Added"),
     I18N_NOOP("Commit Deleted"),
     I18N_NOOP("Commit Replaced"),
-    QString::null, //tx delta -> making ticks instead
-    QString::null, //svn_wc_notify_blame_revision - using ticks
+    QString(), //tx delta -> making ticks instead
+    QString(), //svn_wc_notify_blame_revision - using ticks
     I18N_NOOP("Locking"),
     I18N_NOOP("Unlocked"),
     I18N_NOOP("Lock failed"),
@@ -87,13 +88,13 @@ const QString CContextListener::action_strings[]={
 };
 
 const QString CContextListener::notify_state_strings[]={
-    QString::null, // = 0
-    QString::null,
+    QString(), // = 0
+    QString(),
     I18N_NOOP("unchanged"),
     I18N_NOOP("item wasn't present"),
     I18N_NOOP("unversioned item obstructed work"),
     // I18N_NOOP("Pristine state was modified."), // should send a signal with path instead of message?
-    QString::null,
+    QString(),
     I18N_NOOP("Modified state had mods merged in."),
     I18N_NOOP("Modified state got conflicting mods.")
 };
@@ -101,14 +102,14 @@ const QString CContextListener::notify_state_strings[]={
 QString CContextListener::NotifyAction(svn_wc_notify_action_t action)
 {
     if (action>=smax_actionstring||action<0) {
-        return QString::null;
+        return QString();
     }
     return action_strings[action].isEmpty() ? QString(): /*i18n(*/action_strings[action]/*)*/;
 }
 
 QString CContextListener::NotifyState(svn_wc_notify_state_t state)
 {
-    if (state > svn_wc_notify_state_conflicted || state<0) return QString::null;
+    if (state > svn_wc_notify_state_conflicted || state<0) return QString();
     return notify_state_strings[state].isEmpty()?QString():/*i18n(*/notify_state_strings[state]/*)*/;
 }
 
@@ -133,8 +134,13 @@ bool CContextListener::contextGetCachedLogin (const QString & realm,QString & us
 
 bool CContextListener::contextGetSavedLogin (const QString & realm,QString & username,QString & password)
 {
+    if (!Kdesvnsettings::passwords_in_wallet()) {
+        return true;
+    }
+    emit waitShow(true);
     PwStorage::self()->getLogin(realm,username,password);
     PwStorage::self()->setCachedLogin(realm,username,password);
+    emit waitShow(false);
     /* the return value isn't interesting to us... */
     return true;
 }
@@ -272,12 +278,12 @@ bool CContextListener::contextSslClientCertPrompt (QString & certFile)
 {
     kDebug(9510)<< certFile << endl;
     emit waitShow(true);
-//     QString afile = KFileDialog::getOpenFileName(QString::null,
-//         QString::null,
+//     QString afile = KFileDialog::getOpenFileName(QString(),
+//         QString(),
 //         0,
 //         i18n("Open a file with a #PKCS12 certificate"));
     QString afile = KFileDialog::getOpenFileName(KUrl(),
-        QString::null,
+        QString(),
         0,
         i18n("Open a file with a #PKCS12 certificate"));
     emit waitShow(false);
@@ -360,4 +366,19 @@ void CContextListener::contextProgress(long long int current, long long int max)
     emit netProgress(current,max);
 }
 
+void CContextListener::maySavePlaintext(svn_boolean_t *may_save_plaintext, const QString&realmstring)
+{
+    emit waitShow(true);
+    if (may_save_plaintext) {
+        QString question = i18n("%1\nRealy store password as plain text?",realmstring);
+        QString head = i18n("Save password");
+        if (KMessageBox::questionYesNo(0,question,head)==KMessageBox::Yes) {
+            *may_save_plaintext = true;
+        } else {
+            *may_save_plaintext = false;
+        }
+    }
+    emit waitShow(false);
+}
+
 #include "ccontextlistener.moc"
