@@ -260,7 +260,7 @@ int CommandExec::exec(KCmdLineArgs*args)
         if (l.count()>0) {
             tmp=l[0];
         }
-        while (tmp.endsWith("/")) {
+        while (tmp.endsWith('/')) {
             tmp.truncate(tmp.length()-1);
         }
         m_pCPart->url.append(tmp);
@@ -347,7 +347,10 @@ void CommandExec::slotCmd_log()
     if (m_pCPart->extraRevisions[0]==svn::Revision::WORKING) {
         m_pCPart->extraRevisions[0]=svn::Revision::UNDEFINED;
     }
-    m_pCPart->m_SvnWrapper->makeLog(m_pCPart->start,m_pCPart->end,m_pCPart->extraRevisions[0],m_pCPart->url[0],list,limit);
+    m_pCPart->m_SvnWrapper->makeLog(m_pCPart->start,m_pCPart->end,m_pCPart->extraRevisions[0],m_pCPart->url[0],
+            Kdesvnsettings::log_follows_nodes(),
+            list,
+            limit);
 }
 
 void CommandExec::slotCmd_tree()
@@ -542,7 +545,7 @@ void CommandExec::slotCmd_add()
 
 void CommandExec::slotCmd_revert()
 {
-    m_pCPart->m_SvnWrapper->slotRevertItems(m_pCPart->url);
+    m_pCPart->m_SvnWrapper->slotRevertItems(m_pCPart->url,false);
 }
 
 void CommandExec::slotCmd_addnew()
@@ -556,7 +559,7 @@ void CommandExec::slotCmd_addnew()
 bool CommandExec::scanRevision()
 {
     QString revstring = m_pCPart->args->getOption("r");
-    QStringList revl = revstring.split(":",QString::SkipEmptyParts);
+    QStringList revl = revstring.split(':',QString::SkipEmptyParts);
     if (revl.count()==0) {
         return false;
     }
