@@ -37,8 +37,8 @@ CopyMoveView_impl::CopyMoveView_impl(const QString&baseName,const QString&source
     setObjectName(name);
 
     m_BaseName = baseName;
-    if (m_BaseName.length()>0 && !m_BaseName.endsWith("/")) {
-        m_BaseName+="/";
+    if (m_BaseName.length()>0 && !m_BaseName.endsWith('/')) {
+        m_BaseName+='/';
     }
     m_PrefixLabel->setText(m_BaseName);
     m_OldNameLabel->setText("<b>"+sourceName+"</b>");
@@ -103,7 +103,7 @@ QString CopyMoveView_impl::getMoveCopyTo(bool*ok,bool*force,bool move,
     dlg.setMainWidget(Dialog1Layout);
 
     CopyMoveView_impl*ptr=new CopyMoveView_impl(base,old,(move),Dialog1Layout);
-    QString nName = QString::null;
+    QString nName;
     dlg.resize( QSize(500,160).expandedTo(dlg.minimumSizeHint()) );
     if (dlg.exec()!=QDialog::Accepted) {
         if (ok) *ok = false;
