@@ -150,7 +150,7 @@ void RevGraphView::dotExit(int exitcode,QProcess::ExitStatus exitStatus)
     }
     // remove line breaks when lines to long
     QRegExp endslash("\\\\\\n");
-    dotOutput.replace(endslash,"");
+    dotOutput.remove(endslash);
     double scale = 1.0, scaleX = 1.0, scaleY = 1.0;
     double dotWidth, dotHeight;
     QTextStream* dotStream = new QTextStream(&dotOutput, QIODevice::ReadOnly);
@@ -451,7 +451,8 @@ void RevGraphView::dumpRevtree()
     }
     QTextStream stream(dotTmpFile);
     QFont f = KGlobalSettings::fixedFont();
-    int _fontsize=f.pointSize();
+    QFontMetrics _fm(KGlobalSettings::fixedFont());
+    int _fontsize = _fm.height();
     if (_fontsize<0) {
         _fontsize=10;
     }
@@ -508,13 +509,13 @@ void RevGraphView::dumpRevtree()
 
 QString RevGraphView::toolTip(const QString&_nodename,bool full)const
 {
-    QString res = QString::null;
+    QString res;
     trevTree::ConstIterator it;
     it = m_Tree.find(_nodename);
     if (it==m_Tree.end()) {
         return res;
     }
-    QStringList sp = it.value().Message.split("\n");
+    QStringList sp = it.value().Message.split('\n');
     QString sm;
     if (sp.count()==0) {
         sm = it.value().Message;
