@@ -22,7 +22,9 @@
 #include "src/svnqt/log_entry.hpp"
 #include "src/svnqt/cache/LogCache.hpp"
 #include "src/svnqt/cache/ReposLog.hpp"
+#include "src/svnqt/cache/ReposConfig.hpp"
 #include "src/svnqt/url.hpp"
+#include "src/svnqt/client_parameter.hpp"
 #include "helpers/sub2qt.h"
 #include "revtreewidget.h"
 #include "revgraphview.h"
@@ -90,18 +92,21 @@ bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const
     if (!m_Listener||!m_Client) {
         return false;
     }
+    svn::LogParameter params;
+    params.targets(reposRoot).revisionRange(endr,startr).peg(startr).limit(0).discoverChangedPathes(true).strictNodeHistory(false);
+    QStringList ex = svn::cache::ReposConfig::self()->readEntry(reposRoot,"tree_exclude_list",QStringList());
     try {
         CursorStack a(Qt::BusyCursor);
         StopDlg sdlg(m_Listener,dlgParent,
                      0,"Logs",i18n("Getting logs - hit cancel for abort"));
         if (svn::Url::isLocal(reposRoot) ) {
-            m_Client->log(reposRoot,endr,startr,m_OldHistory,startr,true,false,0);
+            m_Client->log(params.excludeList(ex),m_OldHistory);
         } else {
             svn::cache::ReposLog rl(m_Client,reposRoot);
             if (rl.isValid()) {
-                rl.simpleLog(m_OldHistory,startr,endr,(!Kdesvnsettings::network_on()||!Kdesvnsettings::fill_cache_on_tree()));
+                rl.simpleLog(m_OldHistory,startr,endr,(!Kdesvnsettings::network_on()||!Kdesvnsettings::fill_cache_on_tree()),ex);
             } else if (Kdesvnsettings::network_on()) {
-                m_Client->log(reposRoot,endr,startr,m_OldHistory,startr,true,false,0);
+                m_Client->log(params.excludeList(ex),m_OldHistory);
             } else {
                 KMessageBox::error(0,i18n("Could not retrieve logs, reason:\n%1",i18n("No logcache possible due broken database and networking not allowed.")));
                 return false;
@@ -319,7 +324,7 @@ bool RevisionTree::topDownScan()
                 m_Data->progress->setLabelText(label);
                 kapp->processEvents();
             }
-            m_Data->m_History[j].addCopyTo(m_Data->m_OldHistory[j].changedPaths[i].path,QString::null,-1,m_Data->m_OldHistory[j].changedPaths[i].action);
+            m_Data->m_History[j].addCopyTo(m_Data->m_OldHistory[j].changedPaths[i].path,QString(),-1,m_Data->m_OldHistory[j].changedPaths[i].action);
         }
         m_Data->m_History[j].author=m_Data->m_OldHistory[j].author;
         m_Data->m_History[j].date=m_Data->m_OldHistory[j].date;
@@ -332,7 +337,7 @@ bool RevisionTree::topDownScan()
 bool RevisionTree::isParent(const QString&_par,const QString&tar)
 {
     if (_par==tar) return true;
-    QString par = _par+(_par.endsWith("/")?"":"/");
+    QString par = _par.endsWith('/')?_par:_par+'/';
     return tar.startsWith(par);
 }
 
@@ -344,8 +349,8 @@ bool RevisionTree::isValid()const
 static QString uniqueNodeName(long rev,const QString&path)
 {
     QString res = KCodecs::base64Encode(path.toLocal8Bit(),false);
-    res.replace("\"","_quot_");
-    res.replace(" ","_space_");
+    res.replace('\"',"_quot_");
+    res.replace(' ',"_space_");
     QString n; n.sprintf("%05ld",rev);
     res = "\""+n+QString("_%1\"").arg(res);
     return res;
