@@ -27,9 +27,6 @@
 #include <qwidget.h>
 
 class QVBoxLayout;
-class QHBoxLayout;
-class QGridLayout;
-class QSpacerItem;
 class RevGraphView;
 class QSplitter;
 class KTextBrowser;
@@ -45,7 +42,7 @@ class RevTreeWidget : public QWidget
     Q_OBJECT
 
 public:
-    RevTreeWidget(QObject*,svn::Client*,QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
+    RevTreeWidget(QObject*,svn::Client*,QWidget* parent = 0, const char* name = 0);
     ~RevTreeWidget();
 
     QSplitter* m_Splitter;
