@@ -22,6 +22,8 @@
 #include "models/svnitemmodel.h"
 #include "models/svnitemnode.h"
 #include "models/svnsortfilter.h"
+#include "models/svndirsortfilter.h"
+#include "database/dbsettings.h"
 #include "cursorstack.h"
 #include "svnactions.h"
 #include "copymoveview_impl.h"
@@ -66,15 +68,15 @@ public:
         m_Collection=0;
         m_Model = 0;
         m_SortModel=0;
+        m_DirSortModel = 0;
         m_remoteRevision=svn::Revision::UNDEFINED;
-        tipTimer=0;
     }
 
     ~MainTreeWidgetData()
     {
         delete m_Model;
         delete m_SortModel;
-        delete tipTimer;
+        delete m_DirSortModel;
     }
 
     QModelIndex srcInd(const QModelIndex&ind)
@@ -82,12 +84,17 @@ public:
         return m_SortModel->mapToSource(ind);
     }
 
-    SvnItemModelNode*sourceNode(const QModelIndex&index)
+    QModelIndex srcDirInd(const QModelIndex&ind)
+    {
+        return m_DirSortModel->mapToSource(ind);
+    }
+
+    SvnItemModelNode*sourceNode(const QModelIndex&index,bool left)
     {
         if (!index.isValid()) {
             return 0;
         }
-        QModelIndex ind = m_SortModel->mapToSource(index);
+        QModelIndex ind = left?m_DirSortModel->mapToSource(index):m_SortModel->mapToSource(index);
         if (ind.isValid()) {
             return static_cast<SvnItemModelNode*>(ind.internalPointer());
         }
@@ -97,8 +104,8 @@ public:
     KActionCollection*m_Collection;
     SvnItemModel*m_Model;
     SvnSortFilterProxy*m_SortModel;
+    SvnDirSortFilterProxy*m_DirSortModel;
     svn::Revision m_remoteRevision;
-    QTimer*tipTimer;
     QString merge_Target,merge_Src2,merge_Src1;
 };
 
@@ -114,26 +121,35 @@ MainTreeWidget::MainTreeWidget(KActionCollection*aCollection,QWidget*parent,Qt::
     m_Data->m_SortModel->setDynamicSortFilter(true);
     m_Data->m_SortModel->setSortRole(SORT_ROLE);
     m_Data->m_SortModel->setSortCaseSensitivity(Kdesvnsettings::case_sensitive_sort()?Qt::CaseSensitive:Qt::CaseInsensitive);
-    m_TreeView->sortByColumn(0,Qt::AscendingOrder);
+    m_Data->m_SortModel->sort(0);
     m_TreeView->setModel(m_Data->m_SortModel);
+    m_TreeView->sortByColumn(0,Qt::AscendingOrder);
     m_Data->m_Model = new SvnItemModel(this);
     m_Data->m_SortModel->setSourceSvnModel(m_Data->m_Model);
 
-    m_Data->tipTimer = new QTimer(this);
-    m_Data->tipTimer->setSingleShot(true);
-    connect(m_Data->tipTimer, SIGNAL(timeout()),
-            this, SLOT(hideTips()));
+    m_Data->m_DirSortModel = new SvnDirSortFilterProxy();
+    m_Data->m_DirSortModel->setDynamicSortFilter(true);
+    m_Data->m_DirSortModel->setSortRole(SORT_ROLE);
+    m_Data->m_DirSortModel->setSortCaseSensitivity(Kdesvnsettings::case_sensitive_sort()?Qt::CaseSensitive:Qt::CaseInsensitive);
+
+    m_DirTreeView->setModel(m_Data->m_DirSortModel);
+    m_Data->m_DirSortModel->setSourceSvnModel(m_Data->m_Model);
+
     connect(m_TreeView->selectionModel(),
         SIGNAL(selectionChanged(const QItemSelection&,const QItemSelection&)),
         this,SLOT(slotSelectionChanged(const QItemSelection&,const QItemSelection&)));
 
+    connect(m_DirTreeView->selectionModel(),
+        SIGNAL(selectionChanged(const QItemSelection&,const QItemSelection&)),
+        this,SLOT(slotDirSelectionChanged(const QItemSelection&,const QItemSelection&)));
+
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(clientException(const QString&)),this,SLOT(slotClientException(const QString&)));
     connect(m_Data->m_Model,SIGNAL(clientException(const QString&)),this,SLOT(slotClientException(const QString&)));
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(sendNotify(const QString&)),this,SLOT(slotNotifyMessage(const QString&)));
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(reinitItem(SvnItem*)),this,SLOT(slotReinitItem(SvnItem*)));
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(sigRefreshAll()),this,SLOT(refreshCurrentTree()));
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(sigRefreshCurrent(SvnItem*)),this,SLOT(refreshCurrent(SvnItem*)));
-    //connect(m_Data->m_Model->svqnWrapper(),SIGNAL(sigRefreshIcons(bool)),this,SLOT(slotRescanIcons(bool)));
+    connect(m_Data->m_Model->svnWrapper(),SIGNAL(sigRefreshIcons()),this,SLOT(slotRescanIcons()));
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(sigGotourl(const QString&)),this,SLOT(_openUrl(const QString&)));
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(sigCacheStatus(qlonglong,qlonglong)),this,SIGNAL(sigCacheStatus(qlonglong,qlonglong)));
     connect(m_Data->m_Model->svnWrapper(),SIGNAL(sigThreadsChanged()),this,SLOT(enableActions()));
@@ -144,6 +160,10 @@ MainTreeWidget::MainTreeWidget(KActionCollection*aCollection,QWidget*parent,Qt::
 
     connect(m_Data->m_Model,SIGNAL(itemsFetched(const QModelIndex&)),this,SLOT(slotItemsInserted(const QModelIndex&)));
 
+    m_TreeView->sortByColumn(0,Qt::AscendingOrder);
+    m_DirTreeView->sortByColumn(0,Qt::AscendingOrder);
+
+    checkUseNavigation(true);
     setupActions();
 }
 
@@ -157,6 +177,16 @@ void MainTreeWidget::_openUrl(const QString&url)
     openUrl(url,true);
 }
 
+void MainTreeWidget::resizeAllColumns()
+{
+    m_TreeView->resizeColumnToContents(SvnItemModel::Name);
+    m_TreeView->resizeColumnToContents(SvnItemModel::Status);
+    m_TreeView->resizeColumnToContents(SvnItemModel::LastRevision);
+    m_TreeView->resizeColumnToContents(SvnItemModel::LastAuthor);
+    m_TreeView->resizeColumnToContents(SvnItemModel::LastDate);
+    m_DirTreeView->resizeColumnToContents(SvnItemModel::Name);
+}
+
 bool MainTreeWidget::openUrl(const KUrl &url,bool noReinit)
 {
     CursorStack a;
@@ -173,7 +203,7 @@ bool MainTreeWidget::openUrl(const KUrl &url,bool noReinit)
     _url.setProtocol(proto);
     proto = _url.url(KUrl::RemoveTrailingSlash);
 
-    QStringList s = proto.split("?");
+    QStringList s = proto.split('?');
     if (s.size()>1) {
         setBaseUri(s[0]);
     } else {
@@ -190,16 +220,16 @@ bool MainTreeWidget::openUrl(const KUrl &url,bool noReinit)
     } else {
         if (url.isLocalFile()) {
             QString s = url.path();
-            while(s.endsWith("/")) {
+            while(s.endsWith('/')) {
                 s.remove(s.length()-1,1);
             }
             QFileInfo fi(s);
             if (fi.exists() && fi.isSymLink()) {
                 QString sl = fi.readLink();
-                if (sl.startsWith("/")) {
+                if (sl.startsWith('/')) {
                     setBaseUri(sl);
                 } else {
-                    fi.setFile(fi.path()+"/"+sl);
+                    fi.setFile(fi.path()+'/'+sl);
                     setBaseUri(fi.absoluteFilePath());
                 }
             } else {
@@ -249,14 +279,10 @@ bool MainTreeWidget::openUrl(const KUrl &url,bool noReinit)
     bool result = m_Data->m_Model->checkDirs(baseUri(),0)>-1;
     if (result && isWorkingCopy()) {
         m_Data->m_Model->svnWrapper()->createModifiedCache(baseUri());
-        m_TreeView->expandToDepth(0);
+        m_DirTreeView->expandToDepth(0);
+        m_DirTreeView->selectionModel()->select(m_Data->m_DirSortModel->mapFromSource(m_Data->m_Model->firstRootIndex()),QItemSelectionModel::Select);
     }
-
-    m_TreeView->resizeColumnToContents(SvnItemModel::Name);
-    m_TreeView->resizeColumnToContents(SvnItemModel::Status);
-    m_TreeView->resizeColumnToContents(SvnItemModel::LastRevision);
-    m_TreeView->resizeColumnToContents(SvnItemModel::LastAuthor);
-    m_TreeView->resizeColumnToContents(SvnItemModel::LastDate);
+    resizeAllColumns();
 
     if (!result) {
         setBaseUri("");
@@ -270,8 +296,7 @@ bool MainTreeWidget::openUrl(const KUrl &url,bool noReinit)
         }
     }
     if (result && Kdesvnsettings::log_cache_on_open()) {
-        kdDebug()<<"Starting logcache"<<endl;
-        m_Data->m_Model->svnWrapper()->startFillCache(baseUri());
+        m_Data->m_Model->svnWrapper()->startFillCache(baseUri(),true);
     }
 
     emit changeCaption(baseUri());
@@ -300,17 +325,45 @@ QWidget*MainTreeWidget::realWidget()
 
 int MainTreeWidget::selectionCount()const
 {
-    return m_TreeView->selectionModel()->selectedRows(0).count();
+    int count = m_TreeView->selectionModel()->selectedRows(0).count();
+    if (count == 0) {
+        if (m_TreeView->rootIndex().isValid()) {
+            return 1;
+        }
+    }
+    return count;
+}
+
+int MainTreeWidget::DirselectionCount()const
+{
+    return m_DirTreeView->selectionModel()->selectedRows(0).count();
 }
 
 void MainTreeWidget::SelectionList(SvnItemList&target)const
 {
     QModelIndexList _mi = m_TreeView->selectionModel()->selectedRows(0);
     if (_mi.count()<1) {
+        QModelIndex ind = m_TreeView->rootIndex();
+        if (ind.isValid()) {
+            // realy! it will remapped to this before setRootIndex! (see below)
+            target.push_back(m_Data->sourceNode(ind,false));
+        }
         return;
     }
     for (int i = 0; i<_mi.count();++i) {
-        target.push_back(m_Data->sourceNode(_mi[i]));
+        target.push_back(m_Data->sourceNode(_mi[i],false));
+    }
+}
+
+void MainTreeWidget::DirSelectionList(SvnItemList&target)const
+{
+    target.clear();
+    QModelIndexList _mi = m_DirTreeView->selectionModel()->selectedRows(0);
+    if (_mi.count()<1) {
+        return;
+    }
+    for (int i = 0; i<_mi.count();++i) {
+        target.push_back(m_Data->sourceNode(_mi[i],true));
     }
 }
 
@@ -318,11 +371,27 @@ QModelIndex MainTreeWidget::SelectedIndex()const
 {
     QModelIndexList _mi = m_TreeView->selectionModel()->selectedRows(0);
     if (_mi.count()!=1) {
+        if (_mi.count()==0) {
+            QModelIndex ind = m_TreeView->rootIndex();
+            if (ind.isValid()) {
+                ind = m_Data->m_SortModel->mapToSource(ind);
+                return ind;
+            }
+        }
         return QModelIndex();
     }
     return m_Data->m_SortModel->mapToSource(_mi[0]);
 }
 
+QModelIndex MainTreeWidget::DirSelectedIndex()const
+{
+    QModelIndexList _mi = m_DirTreeView->selectionModel()->selectedRows(0);
+    if (_mi.count()!=1) {
+        return QModelIndex();
+    }
+    return m_Data->m_DirSortModel->mapToSource(_mi[0]);
+}
+
 SvnItemModelNode* MainTreeWidget::SelectedNode()const
 {
     QModelIndex index = SelectedIndex();
@@ -333,6 +402,16 @@ SvnItemModelNode* MainTreeWidget::SelectedNode()const
     return 0;
 }
 
+SvnItemModelNode* MainTreeWidget::DirSelectedNode()const
+{
+    QModelIndex index = DirSelectedIndex();
+    if (index.isValid()) {
+        SvnItemModelNode*item = static_cast<SvnItemModelNode*>(index.internalPointer());
+        return item;
+    }
+    return 0;
+}
+
 void MainTreeWidget::slotSelectionChanged(const QItemSelection&,const QItemSelection&)
 {
     enableActions();
@@ -344,6 +423,20 @@ SvnItem* MainTreeWidget::Selected()const
     return SelectedNode();
 }
 
+SvnItem* MainTreeWidget::DirSelected()const
+{
+    return DirSelectedNode();
+}
+
+SvnItem* MainTreeWidget::DirSelectedOrMain()const
+{
+    SvnItem*_item=DirSelected();
+    if (_item==0 && isWorkingCopy()) {
+        _item=m_Data->m_Model->firstRootChild();
+    }
+    return _item;
+}
+
 SvnItem* MainTreeWidget::SelectedOrMain()const
 {
     SvnItem*_item=Selected();
@@ -353,43 +446,23 @@ SvnItem* MainTreeWidget::SelectedOrMain()const
     return _item;
 }
 
-bool MainTreeWidget::event(QEvent*event)
-{
-    if (event->type() == QEvent::ToolTip) {
-        hideTips();
-        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
-        QPoint vp = m_TreeView->viewport()->mapFromGlobal(helpEvent->globalPos());
-        QModelIndex mi = m_TreeView->indexAt(vp);
-        if (mi.isValid()) {
-            QModelIndex sm = m_Data->m_SortModel->mapToSource(mi);
-            if (sm.isValid()) {
-                SvnItemModelNode*item = static_cast<SvnItemModelNode*>(sm.internalPointer());
-                QToolTip::showText(helpEvent->globalPos(),item->getToolTipText());
-                m_Data->tipTimer->start(5000);
-            }
-        }
-    }/* else if (event->type()==QEvent::Drop) {
-        kDebug(9510)<<event<<endl;
-    }*/
-    return QWidget::event(event);
-}
-
-void MainTreeWidget::hideTips()
-{
-    m_Data->tipTimer->stop();
-    QToolTip::hideText();
-}
-
 void MainTreeWidget::setupActions()
 {
     if (!m_Data->m_Collection) return;
     KAction*tmp_action;
     /* local and remote actions */
     /* 1. actions on dirs AND files */
-    //new KAction(,"kdesvnlog",,this,SLOT(slotMakeLog()),m_Data->m_Collection,"make_svn_log_full");
     tmp_action = add_action("make_svn_log_full",i18n("History of item"),KShortcut(Qt::CTRL+Qt::Key_L),KIcon("kdesvnlog"),this,SLOT(slotMakeLog()));
     tmp_action->setIconText(i18n("History"));
     tmp_action->setStatusTip(i18n("Displays the history log of selected item"));
+    tmp_action = add_action("make_svn_log_nofollow",i18n("History of item ignoring copies"),KShortcut(Qt::SHIFT+Qt::CTRL+Qt::Key_L),KIcon("kdesvnlog"),this,SLOT(slotMakeLogNoFollow()));
+    tmp_action->setIconText(i18n("History"));
+    tmp_action->setStatusTip(i18n("Displays the history log of selected item without following copies"));
+
+    tmp_action = add_action("make_svn_dir_log_nofollow",i18n("History of item ignoring copies"),KShortcut(),KIcon("kdesvnlog"),this,SLOT(slotDirMakeLogNoFollow()));
+    tmp_action->setIconText(i18n("History"));
+    tmp_action->setStatusTip(i18n("Displays the history log of selected item without following copies"));
+
     tmp_action = add_action("make_svn_tree",i18n("Full revision tree"),KShortcut(Qt::CTRL+Qt::Key_T),KIcon("kdesvntree"),this,SLOT(slotMakeTree()));
     tmp_action->setStatusTip(i18n("Shows history of item as linked tree"));
     tmp_action = add_action("make_svn_partialtree",i18n("Partial revision tree"),KShortcut(Qt::SHIFT+Qt::CTRL+Qt::Key_T),KIcon("kdesvntree"),this,SLOT(slotMakePartTree()));
@@ -482,11 +555,12 @@ void MainTreeWidget::setupActions()
     tmp_action = add_action("make_svn_headupdate",i18n("Update to head"),KShortcut(),KIcon("kdesvnupdate"),m_Data->m_Model->svnWrapper(),SLOT(slotUpdateHeadRec()));
     tmp_action->setIconText(i18n("Update"));
     tmp_action = add_action("make_svn_revupdate",i18n("Update to revision..."),KShortcut(),KIcon("kdesvnupdate"),m_Data->m_Model->svnWrapper(),SLOT(slotUpdateTo()));
-    tmp_action = add_action("make_svn_commit",i18n("Commit"),KShortcut("CTRL+#"),KIcon("kdesvncommit"),m_Data->m_Model->svnWrapper(),SLOT(slotCommit()));
+    tmp_action = add_action("make_svn_commit",i18n("Commit"),KShortcut("CTRL+#"),KIcon("kdesvncommit"),this,SLOT(slotCommit()));
     tmp_action->setIconText(i18n("Commit"));
 
-    tmp_action =
-        add_action("make_svn_basediff",i18n("Diff local changes"),KShortcut(Qt::CTRL+Qt::Key_D),KIcon("kdesvndiff"),this,SLOT(slotSimpleBaseDiff()));
+    tmp_action = add_action("make_svn_basediff",i18n("Diff local changes"),KShortcut(Qt::CTRL+Qt::Key_D),KIcon("kdesvndiff"),this,SLOT(slotSimpleBaseDiff()));
+    tmp_action->setToolTip(i18n("Diff working copy against BASE (last checked out version) - doesn't require access to repository"));
+    tmp_action = add_action("make_svn_dirbasediff",i18n("Diff local changes"),KShortcut(),KIcon("kdesvndiff"),this,SLOT(slotDirSimpleBaseDiff()));
     tmp_action->setToolTip(i18n("Diff working copy against BASE (last checked out version) - doesn't require access to repository"));
 
     tmp_action =
@@ -496,6 +570,9 @@ void MainTreeWidget::setupActions()
     tmp_action =
         add_action("make_svn_itemsdiff",i18n("Diff items"),KShortcut(),KIcon("kdesvndiff"),this,SLOT(slotDiffPathes()));
     tmp_action->setToolTip(i18n("Diff two items"));
+    tmp_action =
+        add_action("make_svn_diritemsdiff",i18n("Diff items"),KShortcut(),KIcon("kdesvndiff"),this,SLOT(slotDiffPathes()));
+    tmp_action->setToolTip(i18n("Diff two items"));
 
 
     tmp_action =
@@ -536,10 +613,11 @@ void MainTreeWidget::setupActions()
     /* caching */
     tmp_action = add_action("update_log_cache",i18n("Update log cache"),KShortcut(),KIcon(),this,SLOT(slotUpdateLogCache()));
     tmp_action->setToolTip(i18n("Update the log cache for current repository"));
-    /*    tmp_action = new KAction( i18n("Stop update log cache"),0,this,SLOT(slotUpdateLogCache()),m_Data->m_Collection,"stop_update_log_cache" );
-        tmp_action->setToolTip(i18n("Stop the update of the log cache"));
-    */
 
+    tmp_action = add_action("make_dir_commit",i18n("Commit"),KShortcut(),KIcon("kdesvncommit"),this,SLOT(slotDirCommit()));
+    tmp_action = add_action("make_dir_update",i18n("Update to head"),KShortcut(),KIcon("kdesvnupdate"),this,SLOT(slotDirUpdate()));
+
+    tmp_action = add_action("show_repository_settings",i18n("Settings for current repository"),KShortcut(),KIcon(),this,SLOT(slotRepositorySettings()));
     enableActions();
 }
 
@@ -570,6 +648,7 @@ void MainTreeWidget::enableActions()
 {
     bool isopen = baseUri().length()>0;
     int c = m_TreeView->selectionModel()->selectedRows(0).count();
+    int d = m_DirTreeView->selectionModel()->selectedRows(0).count();
     SvnItemModelNode*si = SelectedNode();
     bool single = c==1&&isopen;
     bool multi = c>1&&isopen;
@@ -586,7 +665,8 @@ void MainTreeWidget::enableActions()
     QAction * temp = 0;
     /* local and remote actions */
     /* 1. actions on dirs AND files */
-    enableAction("make_svn_log",single||none);
+    enableAction("make_svn_log_nofollow",single||none);
+    enableAction("make_svn_dir_log_nofollow",d==1&&isopen);
     enableAction("make_last_change",isopen);
     enableAction("make_svn_log_full",single||none);
     enableAction("make_svn_tree",single||none);
@@ -625,18 +705,23 @@ void MainTreeWidget::enableActions()
     enableAction("make_try_resolve",conflicted && !dir);
 
     enableAction("make_svn_info",isopen);
-    enableAction("make_svn_merge_revisions",single&&isWorkingCopy());
-    enableAction("make_svn_merge",single||none);
-    enableAction("make_svn_addrec",(multi||single) && isWorkingCopy());
+    enableAction("make_svn_merge_revisions",(single||d==1)&&isWorkingCopy());
+    enableAction("make_svn_merge",single||d==1||none);
+    enableAction("make_svn_addrec",(multi||single||d>0) && isWorkingCopy());
     enableAction("make_svn_headupdate",isWorkingCopy()&&isopen&&remote_enabled);
+    enableAction("make_dir_update",isWorkingCopy()&&isopen&&remote_enabled);
+
     enableAction("make_svn_revupdate",isWorkingCopy()&&isopen&&remote_enabled);
     enableAction("make_svn_commit",isWorkingCopy()&&isopen&&remote_enabled);
+    enableAction("make_dir_commit",isWorkingCopy()&&isopen&&remote_enabled);
 
     enableAction("make_svn_basediff",isWorkingCopy()&&(single||none));
+    enableAction("make_svn_dirbasediff",isWorkingCopy()&&(d<2));
     enableAction("make_svn_headdiff",isWorkingCopy()&&(single||none)&&remote_enabled);
 
     /// @todo check if all items have same type
     enableAction("make_svn_itemsdiff",multi && c==2 && unique && remote_enabled);
+    enableAction("make_svn_diritemsdiff",d==2 && isopen && remote_enabled);
 
     /* 2. on dirs only */
     enableAction("make_cleanup",isWorkingCopy()&& (dir||none));
@@ -654,6 +739,7 @@ void MainTreeWidget::enableActions()
     enableAction("switch_browse_revision",!isWorkingCopy()&&isopen);
     enableAction("make_check_updates",isWorkingCopy()&&isopen && remote_enabled);
     enableAction("openwith",KAuthorized::authorizeKAction("openwith")&&single&&!dir);
+    enableAction("show_repository_settings",isopen);
 
     temp = filesActions()->action("update_log_cache");
     if (temp) {
@@ -728,6 +814,7 @@ void MainTreeWidget::slotSettingsChanged()
     if (m_Data->m_Model->svnWrapper() && !m_Data->m_Model->svnWrapper()->doNetworking()) {
         m_Data->m_Model->svnWrapper()->stopFillCache();
     }
+    checkUseNavigation();
 }
 
 KService::List MainTreeWidget::offersList(SvnItem*item,bool execOnly)const
@@ -756,6 +843,7 @@ void MainTreeWidget::slotItemActivated(const QModelIndex&_index)
 
 void MainTreeWidget::itemActivated(const QModelIndex&index,bool keypress)
 {
+    Q_UNUSED(keypress);
     SvnItemModelNode*item;
     if (index.isValid() && (item=static_cast<SvnItemModelNode*>(index.internalPointer()))) {
         if (!item->isDir()) {
@@ -772,13 +860,14 @@ void MainTreeWidget::itemActivated(const QModelIndex&index,bool keypress)
             } else {
                 KRun::displayOpenWithDialog(lst,KApplication::activeWindow());
             }
-        } else if (keypress){
-            QModelIndex i=m_Data->m_SortModel->mapFromSource(index);
-            if (m_TreeView->isExpanded(i)) {
-                m_TreeView->collapse(i);
-            } else {
-                m_TreeView->expand(i);
+        } else if (Kdesvnsettings::show_navigation_panel()) {
+            m_DirTreeView->selectionModel()->select(m_Data->m_DirSortModel->mapFromSource(index),QItemSelectionModel::ClearAndSelect);
+            QModelIndex _ind = m_Data->m_Model->parent(index);
+            if (_ind.isValid()) {
+                m_DirTreeView->expand(m_Data->m_DirSortModel->mapFromSource(_ind));
             }
+        } else {
+
         }
     }
 }
@@ -817,9 +906,24 @@ void MainTreeWidget::slotIgnore()
     m_Data->m_SortModel->invalidate();
 }
 
+void MainTreeWidget::slotMakeLogNoFollow()const
+{
+    doLog(false,false);
+}
+
 void MainTreeWidget::slotMakeLog()const
 {
-    SvnItem*k=SelectedOrMain();
+    doLog(true,false);
+}
+
+void MainTreeWidget::slotDirMakeLogNoFollow()const
+{
+    doLog(false,true);
+}
+
+void MainTreeWidget::doLog(bool use_follow_settings,bool left)const
+{
+    SvnItem*k=left?DirSelectedOrMain():SelectedOrMain();
     QString what;
     if (k) {
         what=k->fullName();
@@ -834,16 +938,60 @@ void MainTreeWidget::slotMakeLog()const
     }
     svn::Revision end(svn::Revision::START);
     bool list = Kdesvnsettings::self()->log_always_list_changed_files();
-    int l = Kdesvnsettings::self()->maximum_displayed_logs();
-    m_Data->m_Model->svnWrapper()->makeLog(start,end,(isWorkingCopy()?svn::Revision::UNDEFINED:baseRevision()),what,list,l);
+    bool follow = use_follow_settings?Kdesvnsettings::log_follows_nodes():false;
+    Kdesvnsettings::setLast_node_follow(follow);
+    int l = 50;
+    m_Data->m_Model->svnWrapper()->makeLog(start,end,(isWorkingCopy()?svn::Revision::UNDEFINED:baseRevision()),what,follow,list,l);
 }
 
+
 void MainTreeWidget::slotContextMenu(const QPoint&)
 {
-    bool isopen = baseUri().length()>0;
     SvnItemList l;
     SelectionList(l);
+    execContextMenu(l);
+}
 
+void MainTreeWidget::slotDirContextMenu(const QPoint&vp)
+{
+    SvnItemList l;
+    DirSelectionList(l);
+    KMenu popup;
+    QAction * temp = 0;
+    int count = 0;
+    if ( (temp=filesActions()->action("make_dir_commit")) && temp->isEnabled() && ++count) popup.addAction(temp);
+    if ( (temp=filesActions()->action("make_dir_update")) && temp->isEnabled() && ++count) popup.addAction(temp);
+    if ( (temp=filesActions()->action("make_svn_dirbasediff")) && temp->isEnabled() && ++count) popup.addAction(temp);
+    if ( (temp=filesActions()->action("make_svn_diritemsdiff")) && temp->isEnabled() && ++count) popup.addAction(temp);
+    if ( (temp=filesActions()->action("make_svn_dir_log_nofollow")) && temp->isEnabled() && ++count) popup.addAction(temp);
+
+    KService::List offers;
+    OpenContextmenu*me=0;
+    QAction*menuAction = 0;
+
+    if (l.count()==1 && l.at(0)) {
+        offers = offersList(l.at(0),l.at(0)->isDir());
+        if (offers.count()>0) {
+            svn::Revision rev(isWorkingCopy()?svn::Revision::UNDEFINED:baseRevision());
+            me= new OpenContextmenu(l.at(0)->kdeName(rev),offers,0,0);
+            me->setTitle(i18n("Open With..."));
+            menuAction=popup.addMenu(me);
+            ++count;
+        }
+    }
+    if (count) {
+        popup.exec(m_DirTreeView->viewport()->mapToGlobal(vp));
+    }
+    if (menuAction) {
+        popup.removeAction(menuAction);
+    }
+    delete me;
+
+}
+
+void MainTreeWidget::execContextMenu(const SvnItemList&l)
+{
+    bool isopen = baseUri().length()>0;
     QString menuname;
 
     if (!isopen) {
@@ -893,7 +1041,6 @@ void MainTreeWidget::slotContextMenu(const QPoint&)
     if (l.count()==1) offers = offersList(l.at(0),l.at(0)->isDir());
 
     if (l.count()==1/*&&!l.at(0)->isDir()*/) {
-        temp = filesActions()->action("openwith");
         if (offers.count()>0) {
             svn::Revision rev(isWorkingCopy()?svn::Revision::UNDEFINED:baseRevision());
             me= new OpenContextmenu(l.at(0)->kdeName(rev),offers,0,0);
@@ -946,12 +1093,14 @@ void MainTreeWidget::slotSelectBrowsingRevision()
     if (!dlg) {
         return;
     }
+    rdlg->setNoWorking(true);
     rdlg->setStartOnly(true);
     if (dlg->exec()==QDialog::Accepted) {
         Rangeinput_impl::revision_range r = rdlg->getRange();
         m_Data->m_remoteRevision= r.first;
         clear();
         m_Data->m_Model->checkDirs(baseUri(),0);
+        emit changeCaption(baseUri()+"@"+r.first.toString());
     }
     KConfigGroup _k(Kdesvnsettings::self()->config(),"revisions_dlg");
     dlg->saveDialogSize(_k);
@@ -1112,25 +1261,21 @@ void MainTreeWidget::slotDisplayLastDiff()
 
 void MainTreeWidget::slotSimpleBaseDiff()
 {
-    SvnItem*kitem = Selected();
-    if (isWorkingCopy())
-    {
-        chdir(baseUri().toLocal8Bit());
-    }
+    simpleWcDiff(Selected(),svn::Revision::BASE,svn::Revision::WORKING);
+}
 
-    QString what;
-    if (!kitem) {
-        what==".";
-    } else {
-        what = relativePath(kitem);
-    }
-    // only possible on working copies - so we may say this values
-    m_Data->m_Model->svnWrapper()->makeDiff(what,svn::Revision::BASE,svn::Revision::WORKING,svn::Revision::UNDEFINED,kitem?kitem->isDir():true);
+void MainTreeWidget::slotDirSimpleBaseDiff()
+{
+    simpleWcDiff(DirSelected(),svn::Revision::BASE,svn::Revision::WORKING);
 }
 
 void MainTreeWidget::slotSimpleHeadDiff()
 {
-    SvnItem*kitem = Selected();
+    simpleWcDiff(Selected(),svn::Revision::WORKING,svn::Revision::HEAD);
+}
+
+void MainTreeWidget::simpleWcDiff(SvnItem*kitem,const svn::Revision&first,const svn::Revision&second)
+{
     QString what;
     if (isWorkingCopy())
     {
@@ -1143,7 +1288,7 @@ void MainTreeWidget::slotSimpleHeadDiff()
         what = relativePath(kitem);
     }
     // only possible on working copies - so we may say this values
-    m_Data->m_Model->svnWrapper()->makeDiff(what,svn::Revision::WORKING,svn::Revision::HEAD,svn::Revision::UNDEFINED,kitem?kitem->isDir():true);
+    m_Data->m_Model->svnWrapper()->makeDiff(what,first,second,svn::Revision::UNDEFINED,kitem?kitem->isDir():true);
 }
 
 void MainTreeWidget::slotDiffRevisions()
@@ -1179,9 +1324,18 @@ void MainTreeWidget::slotDiffRevisions()
 void MainTreeWidget::slotDiffPathes()
 {
     SvnItemList lst;
-    SelectionList(lst);
 
-    if (lst.count()!=2 || !uniqueTypeSelected()) {
+    QObject * tr = sender();
+    bool unique=false;
+
+    if (tr==filesActions()->action("make_svn_diritemsdiff")) {
+        unique=true;
+        DirSelectionList(lst);
+    } else {
+        SelectionList(lst);
+    }
+
+    if (lst.count()!=2 || (!unique && !uniqueTypeSelected()) ) {
         return;
     }
 
@@ -1402,7 +1556,7 @@ void MainTreeWidget::internalDrop(const KUrl::List&_lst,Qt::DropAction action,co
     KUrl::List::iterator it = lst.begin();
     QStringList l;
     for (;it!=lst.end();++it) {
-        l = (*it).prettyUrl().split("?");
+        l = (*it).prettyUrl().split('?');
         if (l.size()>1) {
             (*it) = l[0];
         } else if (isWorkingCopy())
@@ -1410,7 +1564,7 @@ void MainTreeWidget::internalDrop(const KUrl::List&_lst,Qt::DropAction action,co
             (*it) = KUrl::fromPathOrUrl( (*it).path());
         }
         (*it).setProtocol(nProto);
-        kdDebug()<<"Dropped: "<<(*it)<<endl;
+        kDebug()<<"Dropped: "<<(*it)<<endl;
     }
 
     if (index.isValid()) {
@@ -1423,7 +1577,7 @@ void MainTreeWidget::internalDrop(const KUrl::List&_lst,Qt::DropAction action,co
     if (action==Qt::MoveAction) {
         m_Data->m_Model->svnWrapper()->makeMove(lst,target,false);
     } else if (action==Qt::CopyAction) {
-        m_Data->m_Model->svnWrapper()->makeCopy(lst,target,svn::Revision::HEAD);
+        m_Data->m_Model->svnWrapper()->makeCopy(lst,target,(isWorkingCopy()?svn::Revision::UNDEFINED:baseRevision()));
     }
     refreshCurrentTree();
 }
@@ -1453,6 +1607,9 @@ void MainTreeWidget::slotUrlDropped(const KUrl::List&_lst,Qt::DropAction action,
     QString path = _lst[0].path();
     QFileInfo fi(path);
     if  (!isWorkingCopy()) {
+        if (!fi.isDir()) {
+            target+= '/'+_lst[0].fileName();
+        }
         slotImportIntoDir(_lst[0],target,fi.isDir());
     } else {
         WidgetBlockStack(this);
@@ -1489,6 +1646,15 @@ void MainTreeWidget::slotCopyFinished(KJob*_job)
     refreshCurrentTree();
 }
 
+void MainTreeWidget::stopLogCache()
+{
+    QAction*temp = filesActions()->action("update_log_cache");
+    m_Data->m_Model->svnWrapper()->stopFillCache();
+    if (temp) {
+        temp->setText(i18n("Update log cache"));
+    }
+}
+
 void MainTreeWidget::slotUpdateLogCache()
 {
     if (baseUri().length()>0 && m_Data->m_Model->svnWrapper()->doNetworking()) {
@@ -1676,6 +1842,7 @@ void MainTreeWidget::slotMerge()
     dlg->saveDialogSize(_k);
 
     delete dlg;
+    enableActions();
 }
 
 void MainTreeWidget::slotRelocate()
@@ -1738,10 +1905,6 @@ void MainTreeWidget::slotImportIntoCurrent(bool dirs)
 
     if (uri.url().isEmpty()) return;
 
-    if ( !uri.protocol().isEmpty() && uri.protocol()!="file") {
-        KMessageBox::error(this,i18n("Cannot import into remote targets!"));
-        return;
-    }
     slotImportIntoDir(uri,targetUri,dirs);
 }
 
@@ -1752,8 +1915,12 @@ void MainTreeWidget::slotImportIntoDir(const KUrl&importUrl,const QString&target
 
     KDialog*dlg;
     KUrl uri = importUrl;
+    if ( !uri.protocol().isEmpty() && uri.protocol()!="file") {
+        KMessageBox::error(this,i18n("Cannot import remote urls!"));
+        return;
+    }
     QString targetUri = target;
-    while (targetUri.endsWith("/")) {
+    while (targetUri.endsWith('/')) {
         targetUri.truncate(targetUri.length()-1);
     }
 
@@ -1782,11 +1949,11 @@ void MainTreeWidget::slotImportIntoDir(const KUrl&importUrl,const QString&target
     ptr->saveHistory(false);
     uri.setProtocol("");
     QString iurl = uri.path();
-    while (iurl.endsWith("/")) {
+    while (iurl.endsWith('/')) {
         iurl.truncate(iurl.length()-1);
     }
     if (dirs && ptr2 && ptr2->createDir()) {
-        targetUri+= "/"+uri.fileName();
+        targetUri+= '/'+uri.fileName();
     }
     if (ptr2) {
         m_Data->m_Model->svnWrapper()->slotImport(iurl,targetUri,logMessage,rec,ptr2->noIgnore(),ptr2->ignoreUnknownNodes());
@@ -1891,10 +2058,123 @@ void MainTreeWidget::slotItemExpanded(const QModelIndex&)
 
 void MainTreeWidget::slotItemsInserted(const QModelIndex&)
 {
-    m_TreeView->resizeColumnToContents(SvnItemModel::Name);
-    m_TreeView->resizeColumnToContents(SvnItemModel::Status);
-    m_TreeView->resizeColumnToContents(SvnItemModel::LastAuthor);
-    m_TreeView->resizeColumnToContents(SvnItemModel::LastDate);
+    resizeAllColumns();
+}
+
+void MainTreeWidget::slotDirSelectionChanged(const QItemSelection&_item,const QItemSelection&)
+{
+    QModelIndexList _indexes = _item.indexes();
+    switch (DirselectionCount()) {
+    case 1:
+        m_DirTreeView->setStatusTip(i18n("Hold CTRL key while click on selected item for unselect"));
+        break;
+    case 2:
+        m_DirTreeView->setStatusTip(i18n("See context menu for more actions"));
+        break;
+    case 0:
+        m_DirTreeView->setStatusTip(i18n("Click for navigate"));
+        break;
+    default:
+        m_DirTreeView->setStatusTip(i18n("Navigation"));
+        break;
+    }
+    if (_indexes.size()>=1) {
+        QModelIndex ind = _indexes[0];
+        QModelIndex _t =m_Data->srcDirInd(ind);
+        if (m_Data->m_Model->canFetchMore(_t)) {
+            WidgetBlockStack st(m_TreeView);
+            WidgetBlockStack st2(m_DirTreeView);
+            m_Data->m_Model->fetchMore(_t);
+        }
+        _t = m_Data->m_SortModel->mapFromSource(_t);
+        if (Kdesvnsettings::show_navigation_panel()) m_TreeView->setRootIndex(_t);
+    } else {
+        m_TreeView->setRootIndex(QModelIndex());
+    }
+    if (m_TreeView->selectionModel()->hasSelection()) {
+        m_TreeView->selectionModel()->clearSelection();
+    } else {
+        enableActions();
+    }
+    resizeAllColumns();
+}
+
+void MainTreeWidget::slotCommit()
+{
+    SvnItemList which;
+    SelectionList(which);
+    m_Data->m_Model->svnWrapper()->doCommit(which);
+}
+
+void MainTreeWidget::slotDirCommit()
+{
+    SvnItemList which;
+    DirSelectionList(which);
+    m_Data->m_Model->svnWrapper()->doCommit(which);
+}
+
+void MainTreeWidget::slotDirUpdate()
+{
+    SvnItemList which;
+    DirSelectionList(which);
+    QStringList what;
+    if (which.count()==0) {
+        what.append(baseUri());
+    } else {
+        SvnItemListConstIterator liter=which.begin();
+        for(;liter!=which.end();++liter){
+            what.append((*liter)->fullName());
+        }
+    }
+    m_Data->m_Model->svnWrapper()->makeUpdate(what,svn::Revision::HEAD,true);
+}
+
+void MainTreeWidget::slotRescanIcons()
+{
+    m_Data->m_Model->refreshIndex(m_Data->m_Model->firstRootIndex());
+}
+
+void MainTreeWidget::checkUseNavigation(bool startup)
+{
+    bool use = Kdesvnsettings::show_navigation_panel();
+    if (use) {
+        m_TreeView->collapseAll();
+    }
+    m_TreeView->setExpandsOnDoubleClick(!use);
+    m_TreeView->setRootIsDecorated(!use);
+    m_TreeView->setItemsExpandable(!use);
+    QList<int> si;
+    if (use) {
+        if (!startup) {
+            si = m_ViewSplitter->sizes();
+            if (si.size()==2 && si[0]<5) {
+                si[0]=200;
+                m_ViewSplitter->setSizes(si);
+            }
+            m_DirTreeView->selectionModel()->clearSelection();
+        }
+    } else {
+        si << 0 << 300;
+        m_ViewSplitter->setSizes(si);
+
+    }
+    m_TreeView->setRootIndex(QModelIndex());
+}
+
+void MainTreeWidget::slotRepositorySettings()
+{
+    if (baseUri().length()==0) {
+        return;
+    }
+    svn::InfoEntry inf;
+    if (!m_Data->m_Model->svnWrapper()->singleInfo(baseUri(),baseRevision(),inf)) {
+        return;
+    }
+    if (inf.reposRoot().isEmpty()) {
+        KMessageBox::sorry(KApplication::activeModalWidget(),i18n("Could not retrieve repository."),i18n("SVN Error"));
+    } else {
+        DbSettings::showSettings(inf.reposRoot());
+    }
 }
 
 #include "maintreewidget.moc"
