@@ -27,15 +27,18 @@
 #include "src/svnqt/status.hpp"
 #include "src/svnqt/client.hpp"
 #include "src/svnqt/path.hpp"
+#include "src/svnqt/svnqt_defines.hpp"
 
 #include <klocale.h>
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kdirwatch.h>
+#include <kdebug.h>
 
 #include <QItemSelectionModel>
 #include <QFileInfo>
 #include <QBrush>
+#include <QUuid>
 
 /*****************************
  * Internal data class begin *
@@ -46,6 +49,7 @@ public:
     SvnItemModelData(SvnItemModel*aCb,MainTreeWidget*display)
         :m_rootNode(0),m_Cb(aCb),m_Display(display),m_DirWatch(0)
     {
+        m_Uid = QUuid::createUuid().toString();
     }
 
     virtual ~SvnItemModelData()
@@ -112,6 +116,7 @@ public:
     SvnItemModel*m_Cb;
     MainTreeWidget*m_Display;
     KDirWatch*m_DirWatch;
+    QString m_Uid;
 };
 /*****************************
  * Internal data class end   *
@@ -122,7 +127,6 @@ SvnItemModel::SvnItemModel(MainTreeWidget*display,QObject*parent)
 {
     m_Data->m_SvnActions = new SvnActions(display);
     m_Data->m_rootNode=new SvnItemModelNodeDir(m_Data->m_SvnActions,display);
-    setSupportedDragActions(Qt::CopyAction|Qt::MoveAction);
 }
 
 SvnItemModel::~SvnItemModel()
@@ -143,6 +147,11 @@ QModelIndex SvnItemModel::firstRootIndex()
     return m_Data->indexForNode(firstRootChild());
 }
 
+SvnItemModelNode* SvnItemModel::nodeForIndex(const QModelIndex&index)
+{
+    return m_Data->nodeForIndex(index);
+}
+
 void SvnItemModel::setRootNodeStat(const svn::StatusPtr&stat)
 {
     m_Data->m_rootNode->setStat(stat);
@@ -176,17 +185,21 @@ bool SvnItemModel::hasChildren(const QModelIndex & parent)const
     return static_cast<SvnItemModelNode*>(parent.internalPointer())->NodeHasChilds();
 }
 
-bool SvnItemModel::filterIndex(const QModelIndex&parent,int childRow)const
+bool SvnItemModel::filterIndex(const QModelIndex&parent,int childRow,svnmodel::ItemTypeFlag showOnly)const
 {
+    SvnItemModelNode* node=m_Data->nodeForIndex(parent);
     if (childRow<0) {
         return false;
     }
-    SvnItemModelNode* node=m_Data->nodeForIndex(parent);
-    if (!node->isDir()) {
-        return false;
+    if (!node->NodeIsDir()) {
+        kDebug()<<"Parent ist kein Dir"<<endl;
+       return false;
     }
     SvnItemModelNode*child=static_cast<SvnItemModelNodeDir*>(node)->child(childRow);
     if (child) {
+        if ( (child->isDir()&&!showOnly.testFlag(svnmodel::Dir))  || (!child->isDir()&&!showOnly.testFlag(svnmodel::File)) ) {
+            return true;
+        }
         return m_Data->m_Display->filterOut(child);
     }
     return false;
@@ -203,11 +216,11 @@ QVariant SvnItemModel::data(const QModelIndex&index,int role)const
         case Status:
             return node->infoText();
         case LastRevision:
-            return QString("%1").arg(node->cmtRev());
+            return QVariant(QLONG(node->cmtRev()));
         case LastAuthor:
             return node->cmtAuthor();
         case LastDate:
-            return KGlobal::locale()->formatDateTime(node->fullDate());
+            return node->fullDate();
         case Locked:
             return node->lockOwner();
         }
@@ -245,6 +258,13 @@ QVariant SvnItemModel::data(const QModelIndex&index,int role)const
                 return QBrush(cl);
             }
         }
+    case Qt::ToolTipRole:
+        {
+            switch(index.column()) {
+                case Name:
+                    return node->getToolTipText();
+            }
+        }
     }
     return QVariant();
 }
@@ -323,7 +343,7 @@ int SvnItemModel::checkDirs(const QString&_what,SvnItemModelNode*_parent)
 
     QString what = _what;
     svn::StatusEntries dlist;
-    while (what.endsWith("/")) {
+    while (what.endsWith('/')) {
         what.truncate(what.length()-1);
     }
     // prevent this from checking unversioned folder. FIXME: what happen when we do open url on a non-working-copy folder??
@@ -351,7 +371,7 @@ int SvnItemModel::checkDirs(const QString&_what,SvnItemModelNode*_parent)
                     node=new SvnItemModelNode(m_Data->m_rootNode,svnWrapper(),m_Data->m_Display);
                 }
                 node->setStat((*it));
-                m_Data->m_rootNode->m_Childs.prepend(node);
+                m_Data->m_rootNode->m_Children.prepend(node);
                 endInsertRows();
             }
             dlist.erase(it);
@@ -395,7 +415,7 @@ void SvnItemModel::insertDirs(SvnItemModelNode*_parent,svn::StatusEntries&dlist)
                 m_Data->addWatchFile(node->fullName());
             }
         }
-        parent->m_Childs.append(node);
+        parent->m_Children.append(node);
     }
     endInsertRows();
 }
@@ -469,27 +489,17 @@ QStringList SvnItemModel::mimeTypes( ) const
                         << QLatin1String( "application/x-kde-urilist" );
 }
 
-bool SvnItemModel::dropMimeData(const QMimeData * data, Qt::DropAction action, int row, int column,const QModelIndex & parent)
+bool SvnItemModel::dropUrls(const KUrl::List& data, Qt::DropAction action, int row, int column,const QModelIndex & parent,bool intern)
 {
     Q_UNUSED(row);
     Q_UNUSED(column);
-    if (!data->hasFormat(QLatin1String("text/uri-list")) &&
-        !data->hasFormat(QLatin1String( "application/x-kde-urilist" )) ) {
-        return false;
-    }
     if (action==Qt::IgnoreAction) {
         return true;
     }
     if (action==Qt::LinkAction) {
         return false;
     }
-    bool intern=false;
-    KUrl::MetaDataMap metaMap;
-    KUrl::List lst = KUrl::List::fromMimeData(data,&metaMap);
-    if (metaMap.find("kdesvn-source")!=metaMap.end()) {
-        intern=true;
-    }
-    emit urlDropped(lst,action,parent,intern);
+    emit urlDropped(data,action,parent,intern);
     return true;
 }
 
@@ -504,6 +514,7 @@ QMimeData* SvnItemModel::mimeData(const QModelIndexList & indexes )const
     QMimeData *data = new QMimeData();
     KUrl::MetaDataMap metaMap;
     metaMap["kdesvn-source"]="t";
+    metaMap["kdesvn-id"]=uniqueIdentifier();
     urls.populateMimeData(data,metaMap);
     return data;
 }
@@ -561,7 +572,7 @@ SvnItemModelNode* SvnItemModel::findPath(const svn::Path&_p)
         if (!n1->isDir()) {
             return 0;
         }
-        QStringList lp = ip.split("/",QString::SkipEmptyParts);
+        QStringList lp = ip.split('/',QString::SkipEmptyParts);
         SvnItemModelNodeDir*d1 = static_cast<SvnItemModelNodeDir*>(n1);
         return d1->findPath(lp);
     }
@@ -583,7 +594,7 @@ void SvnItemModel::initDirWatch()
         connect(m_Data->m_DirWatch,SIGNAL(created(const QString&)),this,SLOT(slotCreated(const QString&)));
         connect(m_Data->m_DirWatch,SIGNAL(deleted(const QString&)),this,SLOT(slotDeleted(const QString&)));
         if (m_Data->m_DirWatch) {
-            m_Data->m_DirWatch->addDir(m_Data->m_Display->baseUri()+"/",KDirWatch::WatchDirOnly);
+            m_Data->m_DirWatch->addDir(m_Data->m_Display->baseUri()+'/',KDirWatch::WatchDirOnly);
             m_Data->m_DirWatch->startScan(true);
         }
     }
@@ -622,11 +633,11 @@ void SvnItemModel::slotDeleted(const QString&what)
         if (!pi.isValid()) {
             return;
         }
-        if (ind.row()>=p->m_Childs.count()) {
+        if (ind.row()>=p->m_Children.count()) {
             return;
         }
         beginRemoveRows(pi,ind.row(),ind.row());
-        p->m_Childs.removeAt(ind.row());
+        p->m_Children.removeAt(ind.row());
         endRemoveRows();
         if (n->isDir()) {
             m_Data->m_DirWatch->removeDir(what);
@@ -643,7 +654,7 @@ void SvnItemModel::checkAddNewItems(const QModelIndex&ind)
     SvnItemModelNodeDir*n = static_cast<SvnItemModelNodeDir*>(ind.internalPointer());
     QString what = n->fullName();
     svn::StatusEntries dlist;
-    while (what.endsWith("/")) {
+    while (what.endsWith('/')) {
         what.truncate(what.length()-1);
     }
     if (!svnWrapper()->makeStatus(what,dlist,m_Data->m_Display->baseRevision(),false,true,true) ) {
@@ -707,8 +718,8 @@ bool SvnItemModel::refreshCurrentTree()
     }
     SvnItemModelNodeDir*_start=m_Data->m_rootNode;
     if (m_Data->m_Display->isWorkingCopy()) {
-        if (m_Data->m_rootNode->m_Childs.size()>0 && m_Data->m_rootNode->m_Childs[0]->NodeIsDir()) {
-            _start=static_cast<SvnItemModelNodeDir*>(m_Data->m_rootNode->m_Childs[0]);
+        if (m_Data->m_rootNode->m_Children.size()>0 && m_Data->m_rootNode->m_Children[0]->NodeIsDir()) {
+            _start=static_cast<SvnItemModelNodeDir*>(m_Data->m_rootNode->m_Children[0]);
             refreshItem(_start);
         } else {
             return false;
@@ -721,7 +732,7 @@ bool SvnItemModel::refreshCurrentTree()
         check_created=true;
     }
     return refreshDirnode(_start,check_created);
-    //emit dataChanged(QModelIndex(),0,m_Data->m_rootNode->m_Childs.size());
+    //emit dataChanged(QModelIndex(),0,m_Data->m_rootNode->m_Children.size());
 }
 
 bool SvnItemModel::refreshDirnode(SvnItemModelNodeDir*node,bool check_empty,bool notrec)
@@ -738,7 +749,7 @@ bool SvnItemModel::refreshDirnode(SvnItemModelNodeDir*node,bool check_empty,bool
     }
     QString what = (node!=m_Data->m_rootNode)?node->fullName():m_Data->m_Display->baseUri();
 
-    if (node->m_Childs.size()==0 && !check_empty) {
+    if (node->m_Children.size()==0 && !check_empty) {
         if (node->fullName()==m_Data->m_Display->baseUri()) {
             return refreshItem(node);
         }
@@ -765,18 +776,18 @@ bool SvnItemModel::refreshDirnode(SvnItemModelNodeDir*node,bool check_empty,bool
         }
     }
     QModelIndex ind = m_Data->indexForNode(node);
-    for (int i = 0;i<node->m_Childs.size();++i) {
+    for (int i = 0;i<node->m_Children.size();++i) {
         bool found = false;
         for (it=dlist.begin();it!=dlist.end();++it) {
-            if ((*it)->path()==node->m_Childs[i]->fullName()) {
+            if ((*it)->path()==node->m_Children[i]->fullName()) {
                 found = true;
                 break;
             }
         }
         if (!found) {
-            SvnItemModelNode*n=node->m_Childs[i];
+            SvnItemModelNode*n=node->m_Children[i];
             beginRemoveRows(ind,i,i);
-            node->m_Childs.removeAt(i);
+            node->m_Children.removeAt(i);
             delete n;
             endRemoveRows();
             --i;
@@ -786,11 +797,11 @@ bool SvnItemModel::refreshDirnode(SvnItemModelNodeDir*node,bool check_empty,bool
     for (it=dlist.begin();it!=dlist.end();) {
         index = node->indexOf((*it)->path());
         if (index!=-1) {
-            node->m_Childs[index]->setStat((*it));
-            if (node->m_Childs[index]->NodeIsDir()!=node->m_Childs[index]->isDir()) {
-                SvnItemModelNode*n=node->m_Childs[index];
+            node->m_Children[index]->setStat((*it));
+            if (node->m_Children[index]->NodeIsDir()!=node->m_Children[index]->isDir()) {
+                SvnItemModelNode*n=node->m_Children[index];
                 beginRemoveRows(ind,index,index);
-                node->m_Childs.removeAt(index);
+                node->m_Children.removeAt(index);
                 delete n;
                 endRemoveRows();
             } else {
@@ -802,11 +813,11 @@ bool SvnItemModel::refreshDirnode(SvnItemModelNodeDir*node,bool check_empty,bool
     }
 
     // make sure that we do not read in the whole tree when just refreshing the current tree.
-    if (node->m_Childs.size()>0 && !notrec) {
-        for (int i=0; i<node->m_Childs.size();++i) {
-            if (node->m_Childs[i]->NodeIsDir()) {
+    if (node->m_Children.size()>0 && !notrec) {
+        for (int i=0; i<node->m_Children.size();++i) {
+            if (node->m_Children[i]->NodeIsDir()) {
                 // both other parameters makes no sense at this point - defaults
-                refreshDirnode(static_cast<SvnItemModelNodeDir*>(node->m_Childs[i]),false,false);
+                refreshDirnode(static_cast<SvnItemModelNodeDir*>(node->m_Children[i]),false,false);
             }
         }
     }
@@ -847,4 +858,9 @@ int SvnItemModel::checkUnversionedDirs(SvnItemModelNode* _parent)
     return dlist.size();
 }
 
+const QString&SvnItemModel::uniqueIdentifier()const
+{
+    return m_Data->m_Uid;
+}
+
 #include "svnitemmodel.moc"
