@@ -76,32 +76,24 @@ SvnLogDlgImp::SvnLogDlgImp(SvnActions*ac,QWidget *parent, const char *name,bool
         m_ChangedList->hide();
     }
     m_Actions = ac;
-    ///FIXME port QTextStream hell into Qt4 QSplitter save/restore state methods
     KConfigGroup cs(Kdesvnsettings::self()->config(), groupName);
-    QString t1 = cs.readEntry("logsplitter",QString());
+    QByteArray t1 = cs.readEntry("logsplitter",QByteArray());
     if (!t1.isEmpty()) {
-        QTextStream st2(&t1,QIODevice::ReadOnly);
-        st2 >> *m_centralSplitter;
+        m_centralSplitter->restoreState(t1);
     }
-    t1 = cs.readEntry("right_logsplitter",QString());
+    t1 = cs.readEntry("right_logsplitter",QByteArray());
     if (!t1.isEmpty()) {
         if (cs.readEntry("laststate",false)==m_ChangedList->isHidden()) {
-            QTextStream st2(&t1,QIODevice::ReadOnly);
-            st2 >> *m_rightSplitter;
+            m_rightSplitter->restoreState(t1);
         }
     }
 }
 
 SvnLogDlgImp::~SvnLogDlgImp()
 {
-    QString t1,t2;
-    QTextStream st1(&t1,QIODevice::WriteOnly);
-    st1 << *m_rightSplitter;
-    QTextStream st2(&t2,QIODevice::WriteOnly);
-    st2 << *m_centralSplitter;
     KConfigGroup cs(Kdesvnsettings::self()->config(), groupName);
-    cs.writeEntry("right_logsplitter",t1);
-    cs.writeEntry("logsplitter",t2);
+    cs.writeEntry("right_logsplitter",m_rightSplitter->saveState());
+    cs.writeEntry("logsplitter",m_centralSplitter->saveState());
     cs.writeEntry("laststate",m_ChangedList->isHidden());
     delete m_SortModel;
 }
@@ -124,7 +116,7 @@ void SvnLogDlgImp::dispLog(const svn::SharedPointer<svn::LogEntriesMap>&_log,con
             QString reg;
             s = m_Actions->searchProperty(reg,"bugtraq:logregex",pegUrl,peg,true);
             if (!s.isNull() && !reg.isEmpty()) {
-                QStringList s1 = reg.split("\n");
+                QStringList s1 = reg.split('\n');
                 if (s1.size()>0) {
                     _r1.setPattern(s1[0]);
                     if (s1.size()>1) {
@@ -333,7 +325,35 @@ void SvnLogDlgImp::slotGetLogs()
 {
     svn::SharedPointer<svn::LogEntriesMap> lm = m_Actions->getLog(m_startRevButton->revision(),
             m_endRevButton->revision(),m_peg,
-            _base+"/"+_name,Kdesvnsettings::self()->log_always_list_changed_files(),0,this);
+            _base+'/'+_name,Kdesvnsettings::self()->log_always_list_changed_files(),0,Kdesvnsettings::last_node_follow(),this);
+    if (lm) {
+        dispLog(lm);
+    }
+}
+
+void SvnLogDlgImp::slotPrevFifty()
+{
+    svn::Revision now = m_CurrentModel->min();
+    if (now == 1) {
+        return;
+    }
+    svn::Revision begin=now.revnum()-1;
+    if (begin.revnum()<1) {
+        begin = 1;
+    }
+    svn::SharedPointer<svn::LogEntriesMap> lm = m_Actions->getLog(begin,
+                            (begin.revnum()>50?svn::Revision::START:svn::Revision::HEAD),m_peg,
+                            _base+'/'+_name,Kdesvnsettings::self()->log_always_list_changed_files(),50,Kdesvnsettings::last_node_follow(),this);
+    if (lm) {
+        dispLog(lm);
+    }
+}
+
+void SvnLogDlgImp::slotBeginHead()
+{
+    svn::SharedPointer<svn::LogEntriesMap> lm = m_Actions->getLog(svn::Revision::HEAD,
+                                        1,m_peg,
+                                        _base+'/'+_name,Kdesvnsettings::self()->log_always_list_changed_files(),50,Kdesvnsettings::last_node_follow(),this);
     if (lm) {
         dispLog(lm);
     }
@@ -348,7 +368,8 @@ void SvnLogDlgImp::slotListEntries()
         return;
     }
     if (ptr->changedPaths().count()==0) {
-        svn::SharedPointer<svn::LogEntriesMap>_log = m_Actions->getLog(ptr->revision(),ptr->revision(),ptr->revision(),_name,true,0);
+        svn::SharedPointer<svn::LogEntriesMap>_log = m_Actions->getLog(ptr->revision(),ptr->revision(),ptr->revision(),
+        _name,true,0,Kdesvnsettings::last_node_follow());
         if (!_log) {
             return;
         }
