@@ -1,3 +1,22 @@
+/***************************************************************************
+ *   Copyright (C) 2005-2009 by Rajko Albrecht  ral@alwins-world.de        *
+ *   http://kdesvn.alwins-world.de/                                        *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
+ ***************************************************************************/
 #include "ReposLog.hpp"
 
 #include "LogCache.hpp"
@@ -6,12 +25,14 @@
 #include "svnqt/client.hpp"
 #include "svnqt/context_listener.hpp"
 #include "svnqt/cache/DatabaseException.hpp"
+#include "svnqt/client_parameter.hpp"
 
 #include <qsqldatabase.h>
 
 #include <QSqlError>
 #include <QSqlQuery>
 #include <QVariant>
+#include <QFileInfo>
 #define Q_LLONG qlonglong
 
 /*!
@@ -23,7 +44,6 @@ svn::cache::ReposLog::ReposLog(svn::Client*aClient,const QString&aRepository)
               m_ReposRoot(aRepository),m_latestHead(svn::Revision::UNDEFINED)
 {
     m_Client=aClient;
-    ContextP ctx = m_Client->getContext();
     if (!aRepository.isEmpty()) {
         m_Database = LogCache::self()->reposDb(aRepository);
     }
@@ -70,7 +90,7 @@ svn::Revision svn::cache::ReposLog::latestCachedRev()
         }
     }
     QString q("select revision from 'logentries' order by revision DESC limit 1");
-    QSqlQuery _q(QString::null, m_Database);
+    QSqlQuery _q(QString(), m_Database);
     if (!_q.exec(q)) {
         //qDebug() << _q.lastError().text();
         return svn::Revision::UNDEFINED;
@@ -86,6 +106,81 @@ svn::Revision svn::cache::ReposLog::latestCachedRev()
     return _r;
 }
 
+qlonglong svn::cache::ReposLog::count()const
+{
+    if (!m_Database.isValid()) {
+        m_Database = LogCache::self()->reposDb(m_ReposRoot);
+        if (!m_Database.isValid()) {
+            return svn::Revision::UNDEFINED;
+        }
+    }
+    QString q("select count(*) from 'logentries'");
+    QSqlQuery _q(QString(), m_Database);
+    if (!_q.exec(q)) {
+        //qDebug() << _q.lastError().text();
+        return -1;
+    }
+    qlonglong _r;
+    QVariant v;
+    if (_q.isActive() && _q.next()) {
+        //qDebug("Sel result: %s",_q.value(0).toString().TOUTF8().data());
+        v=_q.value(0);
+        if (v.canConvert(QVariant::LongLong)) {
+            bool ok = false;
+            _r = v.toLongLong(&ok);
+            if (ok) {
+                return _r;
+            }
+        }
+    }
+    return -1;
+}
+
+qlonglong svn::cache::ReposLog::fileSize()const
+{
+    if (!m_Database.isValid()) {
+        m_Database = LogCache::self()->reposDb(m_ReposRoot);
+        if (!m_Database.isValid()) {
+            return -1;
+        }
+    }
+    QFileInfo fi(m_Database.databaseName());
+    if (fi.exists()) {
+        return fi.size();
+    }
+    return -1;
+}
+
+qlonglong svn::cache::ReposLog::itemCount()const
+{
+    if (!m_Database.isValid()) {
+        m_Database = LogCache::self()->reposDb(m_ReposRoot);
+        if (!m_Database.isValid()) {
+            return -1;
+        }
+    }
+    QString q("select count(*) from 'changeditems'");
+    QSqlQuery _q(QString(), m_Database);
+    if (!_q.exec(q)) {
+        //qDebug() << _q.lastError().text();
+        return -1;
+    }
+    qlonglong _r;
+    QVariant v;
+    if (_q.isActive() && _q.next()) {
+        //qDebug("Sel result: %s",_q.value(0).toString().TOUTF8().data());
+        v=_q.value(0);
+        if (v.canConvert(QVariant::LongLong)) {
+            bool ok = false;
+            _r = v.toLongLong(&ok);
+            if (ok) {
+                return _r;
+            }
+        }
+    }
+    return -1;
+}
+
 bool svn::cache::ReposLog::checkFill(svn::Revision&start,svn::Revision&end,bool checkHead)
 {
     if (!m_Database.isValid()) {
@@ -132,7 +227,9 @@ bool svn::cache::ReposLog::checkFill(svn::Revision&start,svn::Revision&end,bool
     if (_rend==svn::Revision::HEAD||_rend.revnum()>_latest.revnum()) {
         LogEntriesMap _internal;
 //        //qDebug("Retrieving from network.");
-        if (!m_Client->log(m_ReposRoot,_rstart,_rend,_internal,svn::Revision::UNDEFINED,true,false)) {
+        LogParameter params;
+
+        if (!m_Client->log(params.targets(m_ReposRoot).revisionRange(_rstart,_rend).peg(svn::Revision::UNDEFINED).discoverChangedPathes(true).strictNodeHistory(false),_internal)) {
             return false;
         }
         LogEntriesMap::ConstIterator it=_internal.begin();
@@ -160,7 +257,7 @@ bool svn::cache::ReposLog::fillCache(const svn::Revision&_end)
 /*!
     \fn svn::cache::ReposLog::simpleLog(const svn::Revision&start,const svn::Revision&end,LogEntriesMap&target)
  */
-bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_start,const svn::Revision&_end,bool noNetwork)
+bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_start,const svn::Revision&_end,bool noNetwork,const QStringList&exclude)
 {
     if (!m_Client||m_ReposRoot.isEmpty()) {
         return false;
@@ -189,14 +286,16 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_s
     static QString sEntry("select revision,author,date,message from logentries where revision<=? and revision>=?");
     static QString sItems("select changeditem,action,copyfrom,copyfromrev from changeditems where revision=?");
 
-    QSqlQuery bcount(QString::null,m_Database);
+    for (int i = 0; i < exclude.size();++i) {
+        sItems+=" and changeditem not like '"+exclude[i]+"%'";
+    }
+
+    QSqlQuery bcount(QString(),m_Database);
     bcount.prepare(sCount);
 
-    QSqlQuery bcur(QString::null,m_Database);
-    bcur.prepare(sEntry);
+    QSqlQuery bcur(QString(),m_Database);
 
-    QSqlQuery cur(QString::null,m_Database);
-    cur.prepare(sItems);
+    QSqlQuery cur(QString(),m_Database);
 
     bcount.bindValue(0,Q_LLONG(end.revnum()));
     bcount.bindValue(1,Q_LLONG(start.revnum()));
@@ -211,21 +310,23 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_s
         return false;
     }
 
+    bcur.prepare(sEntry);
     bcur.bindValue(0,Q_LLONG(end.revnum()));
     bcur.bindValue(1,Q_LLONG(start.revnum()));
 
     if (!bcur.exec()) {
-        //qDebug() << bcur.lastError().text();
         throw svn::cache::DatabaseException(QString("Could not retrieve values: ")+bcur.lastError().text());
         return false;
     }
     Q_LLONG revision;
     while(bcur.next()) {
+        cur.prepare(sItems);
         revision = bcur.value(0).toLongLong();
         cur.bindValue(0,revision);
+
         if (!cur.exec()) {
             //qDebug() << cur.lastError().text();
-            throw svn::cache::DatabaseException(QString("Could not retrieve values: ")+cur.lastError().text()
+            throw svn::cache::DatabaseException(QString("Could not retrieve revision values: ")+cur.lastError().text()
                     ,cur.lastError().number());
             return false;
         }
@@ -313,7 +414,7 @@ bool svn::cache::ReposLog::_insertLogEntry(const svn::LogEntry&aEntry)
     qlonglong j = aEntry.revision;
     static QString qEntry("insert into logentries (revision,date,author,message) values (?,?,?,?)");
     static QString qPathes("insert into changeditems (revision,changeditem,action,copyfrom,copyfromrev) values (?,?,?,?,?)");
-    QSqlQuery _q(QString::null,m_Database);
+    QSqlQuery _q(QString(),m_Database);
     _q.prepare(qEntry);
     _q.bindValue(0,j);
     _q.bindValue(1,aEntry.date);
@@ -323,7 +424,7 @@ bool svn::cache::ReposLog::_insertLogEntry(const svn::LogEntry&aEntry)
         m_Database.rollback();
         //qDebug("Could not insert values: %s",_q.lastError().text().TOUTF8().data());
         //qDebug() << _q.lastQuery();
-        throw svn::cache::DatabaseException(QString("Could not insert values: ")+_q.lastError().text(),_q.lastError().number());
+        throw svn::cache::DatabaseException(QString("_insertLogEntry_0: Could not insert values: ")+_q.lastError().text(),_q.lastError().number());
     }
     _q.prepare(qPathes);
     svn::LogChangePathEntries::ConstIterator cpit = aEntry.changedPaths.begin();
@@ -373,6 +474,7 @@ bool svn::cache::ReposLog::insertLogEntry(const svn::LogEntry&aEntry)
  */
 bool svn::cache::ReposLog::log(const svn::Path&what,const svn::Revision&_start, const svn::Revision&_end,const svn::Revision&_peg,svn::LogEntriesMap&target, bool strictNodeHistory,int limit)
 {
+    Q_UNUSED(strictNodeHistory);
     static QString s_q("select logentries.revision,logentries.author,logentries.date,logentries.message from logentries where logentries.revision in (select changeditems.revision from changeditems where (changeditems.changeditem='%1' or changeditems.changeditem GLOB '%2/*') %3 GROUP BY changeditems.revision) ORDER BY logentries.revision DESC");
 
     static QString s_e("select changeditem,action,copyfrom,copyfromrev from changeditems where changeditems.revision='%1'");
@@ -391,8 +493,8 @@ bool svn::cache::ReposLog::log(const svn::Path&what,const svn::Revision&_start,
     if (limit>0) {
         query_string+=QString(" LIMIT %1").arg(limit);
     }
-    QSqlQuery _q(QString::null,m_Database);
-    QSqlQuery _q2(QString::null,m_Database);
+    QSqlQuery _q(QString(),m_Database);
+    QSqlQuery _q2(QString(),m_Database);
     _q.prepare(query_string);
     if (!_q.exec()) {
         //qDebug("Could not select values: %s",_q.lastError().text().TOUTF8().data());
@@ -444,10 +546,12 @@ bool svn::cache::ReposLog::itemExists(const svn::Revision&peg,const svn::Path&pa
 {
     /// @todo this moment I have no idea how to check real  with all moves and deletes of parent folders without a hell of sql statements so we make it quite simple: it exists if we found it.
 
+    Q_UNUSED(peg);
+    Q_UNUSED(path);
 
 #if 0
     static QString _s1("select revision from changeditems where changeditem='%1' and action='A' and revision<=%2 order by revision desc limit 1");
-    QSqlQuery _q(QString::null,m_Database);
+    QSqlQuery _q(QString(),m_Database);
     QString query_string=QString(_s1).arg(path.native()).arg(peg.revnum());
     if (!_q.exec(query_string)) {
         //qDebug("Could not select values: %s",_q.lastError().text().TOUTF8().data());
@@ -479,3 +583,28 @@ bool svn::cache::ReposLog::isValid()const
     }
     return true;
 }
+
+void svn::cache::ReposLog::cleanLogEntries()
+{
+
+    if (!isValid()) {
+        return;
+    }
+    m_Database.transaction();
+    QSqlQuery _q(QString(),m_Database);
+    if (!_q.exec("delete from logentries")) {
+        m_Database.rollback();
+        return;
+    }
+    if (!_q.exec("delete from changeditems")) {
+        m_Database.rollback();
+        return;
+    }
+    if (!_q.exec("delete from mergeditems")) {
+        m_Database.rollback();
+        return;
+    }
+
+    m_Database.commit();
+    _q.exec("vacuum");
+}
