@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht
+ * (C) 2005-2007 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -67,7 +67,7 @@ namespace svn
             if (!d.exists(BasePath)) {
                 d.mkdir(BasePath);
             }
-            BasePath=BasePath+"/"+".svnqt";
+            BasePath=BasePath+'/'+".svnqt";
             if (!d.exists(BasePath)) {
                 d.mkdir(BasePath);
             }
