@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht
+ * (C) 2005-2007 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -97,7 +97,7 @@ namespace svn
      * @param context new context to use
      */
     virtual void
-    setContext (ContextP context) = 0;
+    setContext (const ContextP&context) = 0;
 
     /**
      * get a real instance. Result must cleaned with delete.
@@ -112,27 +112,11 @@ namespace svn
      *
      * Throws an exception if an error occurs
      *
-     * @param path Path to explore.
-     * @param descend Recurse into subdirectories if existant.
-     * @param get_all Return all entries, not just the interesting ones.
-     * @param update Query the repository for updates.
-     * @param no_ignore Disregard default and svn:ignore property ignores.
-     * @param hide_externals don't recurse into external definitions
-     * @param revision list specific revision when browsing remote, on working copies parameter will ignored
-     * @param detailed_remote if on remote listing detailed item info should get if possible
-     *                        that may slow so should configureable in frontends!
+     * @param params the parameter for this method
      * @return vector with Status entries.
      */
     virtual StatusEntries
-    status (const Path& path,
-            Depth depth=DepthImmediates,
-            bool get_all = true,
-            bool update = false,
-            bool no_ignore = false,
-            const Revision revision = svn::Revision::HEAD,
-            bool detailed_remote = false,
-            bool hide_externals = false,
-            const StringArray & changelists=StringArray() ) throw (ClientException) = 0;
+    status (const StatusParameter&params) throw (ClientException) = 0;
 
     /**
      * Returns the status of a single file in the path.
@@ -149,23 +133,12 @@ namespace svn
 
   /**
      * Executes a revision checkout.
-     * @param moduleName name of the module to checkout.
-     * @param destPath destination directory for checkout.
-     * @param revision the revision number to checkout. If the number is -1
-     *                 then it will checkout the latest revision.
-     * @param peg Revision to look up
-     * @param recurse whether you want it to checkout files recursively.
-     * @param ignore_externals if true don't process externals definitions.
+     * @param params the parameters to use
+     * @return revision number checked out
      * @exception ClientException
      */
-    virtual svn_revnum_t
-    checkout (const Path& moduleName, const Path & destPath,
-              const Revision & revision,
-              const Revision & peg = Revision::UNDEFINED,
-              svn::Depth depth=DepthInfinity,
-              bool ignore_externals=false,
-              bool overwrite=false
-             ) throw (ClientException) = 0;
+    virtual Revision
+    checkout (const CheckoutParameter&params) throw (ClientException) = 0;
 
     /**
      * relocate wc @a from to @a to
@@ -176,19 +149,11 @@ namespace svn
               const QString &to_url, bool recurse) throw (ClientException)=0;
 
     /**
-     * Sets a single file for deletion.
-     * @exception ClientException
-     */
-    virtual svn::Revision
-            remove (const Path & path, bool force,
-                    bool keep_local = true,
-                    const PropertiesMap&revProps = PropertiesMap()) throw (ClientException)=0;
-
-    /**
-     * Sets files for deletion.
+     * Sets entries for deletion.
      *
      * @param targets targets to delete
      * @param force force if files are locally modified
+     * @param keep_local don't delete entries from hard disk when deleting from working copy
      * @exception ClientException
      */
     virtual svn::Revision
@@ -248,7 +213,7 @@ namespace svn
     virtual QByteArray
     cat (const Path & path,
           const Revision & revision,
-          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
+          const Revision & peg_revision=Revision::UNDEFINED) throw (ClientException)=0;
     /**
      * Retrieves the contents for a specific @a revision of
      * a @a path at @a peg_revision
@@ -278,7 +243,7 @@ namespace svn
     get (const Path & path,
           const QString  & target,
           const Revision & revision,
-          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
+          const Revision & peg_revision=Revision::UNDEFINED) throw (ClientException)=0;
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -291,36 +256,17 @@ namespace svn
      * @param peg indicates in which revision path is valid
      */
     virtual void
-    annotate (AnnotatedFile&target,
-              const Path & path,
-              const Revision & revisionStart,
-              const Revision & revisionEnd,
-              const Revision & peg = Revision::UNDEFINED,
-              const DiffOptions&diffoptions = DiffOptions(),
-              bool ignore_mimetypes = false,
-              bool include_merged_revisions = false
-             ) throw (ClientException)=0;
+    annotate (AnnotatedFile&target,const AnnotateParameter&params) throw (ClientException)=0;
 
     /**
      * Commits changes to the repository. This usually requires
      * authentication, see Auth.
+     * @param parameters CommitParameter to use
      * @return Returns revision transferred or svn::Revision::UNDEFINED if the revision number is invalid.
-     * @param targets files to commit.
-     * @param message log message.
-     * @param depth whether the operation should be done recursively.
-     * @param keep_locks if false unlock items in paths
-     * @param changelist
-     * @param keep_changelist
      * @exception ClientException
      */
     virtual svn::Revision
-    commit (const Targets & targets,
-            const QString& message,
-            svn::Depth depth,bool keep_locks=true,
-            const svn::StringArray&contents=svn::StringArray(),
-            const PropertiesMap&revProps=PropertiesMap(),
-            bool keep_changelist=false
-           ) throw (ClientException)=0;
+    commit (const CommitParameter&parameters) throw (ClientException)=0;
 
     /**
      * Copies a versioned file with the history preserved.
@@ -337,47 +283,15 @@ namespace svn
      * @exception ClientException
      */
     virtual svn::Revision
-    copy (const Targets & srcPath,
-            const Revision & srcRevision,
-            const Revision & pegRevision,
-            const Path & destPath,
-            bool asChild=false,bool makeParent=false,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
+    copy (const CopyParameter&parameter) throw (ClientException)=0;
 
     /**
      * Moves or renames a file.
      * @exception ClientException
      */
     virtual svn::Revision
-    move (const Path & srcPath,
-          const Path & destPath,
-          bool force) throw (ClientException)=0;
-    /**
-     * Moves or renames a file.
-     * @exception ClientException
-     */
-    virtual svn::Revision
-            move (const Targets & srcPath,
-                  const Path & destPath,
-                  bool force,bool asChild,bool makeParent,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
+            move (const CopyParameter&parameter) throw (ClientException)=0;
 
-    /**
-     * Creates a directory directly in a repository or creates a
-     * directory on disk and schedules it for addition. If <i>path</i>
-     * is a URL then authentication is usually required, see Auth and
-     * the callback asks for a logmessage. With subversion 1.4 the target
-     * must not exist (\sa svn_client_move4)
-     *
-     * @param path
-     * @param message log message. if it is QString::null asks when working on repository
-     * @param makeParent create parent folders if not existant (only when build with svn 1.5 or above)
-     * @exception ClientException
-     */
-    virtual svn::Revision
-    mkdir (const Path & path,
-           const QString& message,
-           bool makeParent=true,
-           const PropertiesMap&revProps=PropertiesMap()
-          ) throw (ClientException)=0;
     /**
      * Creates a directory directly in a repository or creates a
      * directory on disk and schedules it for addition. If <i>path</i>
@@ -416,33 +330,18 @@ namespace svn
      * 'clean' directory (meaning a directory with no administrative
      * directories).
      * @exception ClientException
-     * @param srcPath source path
-     * @param destPath a destination path that must not already exist.
-     * @param revision revision to use for the export
-     * @param peg the revision where the path is first looked up when exporting from a repository.
-     * @param overwrite overwrite existing files
-     * @param native_eol Either "LF", "CR" or "CRLF" or NULL.
-     * @param ignore_externals don't process externals definitions as part of this operation.
-     * @param recurse if true, export recursively.<br>
-      Otherwise, export just the directory represented by from and its immediate non-directory children.
+     * @param params Parameter to use
+     * @return revision exported
      */
-    virtual svn_revnum_t
-    doExport (const Path & srcPath,
-              const Path & destPath,
-              const Revision & revision,
-              const Revision & peg = Revision::UNDEFINED,
-              bool overwrite=false,
-              const QString&native_eol=QString::null,
-              bool ignore_externals = false,
-              svn::Depth depth=svn::DepthInfinity
-              ) throw (ClientException)=0;
+    virtual Revision
+    doExport (const CheckoutParameter&params) throw (ClientException)=0;
 
     /**
      * Update local copy to mirror a new url. This excapsulates the
      * svn_client_switch() client method.
      * @exception ClientException
      */
-    virtual svn_revnum_t
+    virtual Revision
     doSwitch (
               const Path & path, const QString& url,
               const Revision & revision,
@@ -476,40 +375,10 @@ namespace svn
      * @exception ClientException
      */
     virtual void
-    merge (const Path & path1, const Revision & revision1,
-           const Path & path2, const Revision & revision2,
-           const Path & localPath, bool force,
-           Depth depth,
-           bool notice_ancestry=false,
-           bool dry_run=false,
-           bool record_only=false,
-           const StringArray&merge_options=StringArray()
-          ) throw (ClientException)=0;
+    merge (const MergeParameter&parameters) throw (ClientException)=0;
 
     virtual void
-    merge_peg(const Path&src,
-              const RevisionRanges&ranges,
-                      const Revision&peg,
-                      const Path&targetWc,
-                      Depth depth,
-                      bool notice_ancestry=false,
-                      bool dry_run=false,
-                      bool force=false,
-                      bool record_only=false,
-                      const StringArray&merge_options=StringArray()
-                     ) throw (ClientException)=0;
-
-    virtual void
-    merge_peg(const Path&src,
-              const RevisionRange&range,
-              const Revision&peg,
-              const Path&targetWc,
-              Depth depth,
-              bool notice_ancestry=false,
-              bool dry_run=false,
-              bool force=false,
-              const StringArray&merge_options=StringArray()
-             ) throw (ClientException)=0;
+    merge_peg(const MergeParameter&parameters) throw (ClientException)=0;
 
     /**
      * Retrieve information for the given path
@@ -525,37 +394,10 @@ namespace svn
     info (const Path &path,
           Depth depth,
           const Revision & rev,
-          const Revision & peg_revision=svn_opt_revision_unspecified,
+          const Revision & peg_revision=Revision::UNDEFINED,
           const StringArray&changelists=StringArray()
          ) throw (ClientException)=0;
 
-    /**
-     * Retrieve log information for the given path
-     * Loads the log messages result set. The first
-     * entry  is the youngest revision.
-     *
-     * You can use the constants Revision::START and
-     * Revision::HEAD
-     *
-     * @param path
-     * @param revisionStart
-     * @param revisionEnd
-     * @param discoverChangedPaths
-     * @param strictNodeHistory
-     * @param limit the maximum log entries count.
-     * @return a vector with log entries
-     */
-    virtual LogEntriesPtr
-    log (const Path& path,
-         const Revision & revisionStart,
-         const Revision & revisionEnd,
-         const Revision & revisionPeg,
-         bool discoverChangedPaths=false,
-         bool strictNodeHistory=true,int limit = 0,
-         bool include_merged_revisions = false,
-         const StringArray&revprops=StringArray()
-        ) throw (ClientException)=0;
-
     /**
      * Retrieve log information for the given path
      * Loads the log messages result set. Result will stored
@@ -564,25 +406,13 @@ namespace svn
      * You can use the constants Revision::START and
      * Revision::HEAD
      *
-     * @param path Path to make a log for
-     * @param revisionStart
-     * @param revisionEnd
-     * @param target the logmap where to store the entries
-     * @param discoverChangedPaths
-     * @param strictNodeHistory
-     * @param limit (ignored when subversion 1.1 API)
+     * @param params Parameter to use for log
+     * @param target where to store the resulting logs
      * @return true if success
+     * @sa LogParameter
      */
     virtual bool
-    log (const Path& path, const Revision & revisionStart,
-         const Revision & revisionEnd,
-         LogEntriesMap&target,
-         const Revision & revisionPeg=Revision::UNDEFINED,
-         bool discoverChangedPaths=false,
-         bool strictNodeHistory=true,int limit = 0,
-         bool include_merged_revisions = false,
-         const StringArray&revprops=StringArray()
-        ) throw (ClientException)=0;
+    log (const LogParameter&params,LogEntriesMap&target) throw (ClientException)=0;
 
     /**
      * Produce diff output which describes the delta between
@@ -592,38 +422,12 @@ namespace svn
      * A ClientException will be thrown if either @a revision1 or
      * @a revision2 has an `unspecified' or unrecognized `kind'.
      *
-     * @param tmpPath prefix for a temporary directory needed by diff.
-     * Filenames will have ".tmp" and similar added to this prefix in
-     * order to ensure uniqueness.
-     * @param path path of the file.
-     * @param revision1 one of the revisions to check.
-     * @param revision2 the other revision.
-     * @param recurse whether the operation should be done recursively.
-     * @param ignoreAncestry whether the files will be checked for
-     * relatedness.
-     * @param noDiffDeleted if true, no diff output will be generated on deleted files.
-     * @param ignore_contenttype if true generate diff even the items are marked as binaries
-     * @param extra extra options for diff ("-b", "-w","--ignore-eol-style")
+     * @param options set of options required for diff
      * @return delta between the files
      * @exception ClientException
      */
     virtual QByteArray
-            diff_peg(const Path & tmpPath, const Path & path,const Path&relativeTo,
-          const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
-          Depth depth, bool ignoreAncestry,
-          bool noDiffDeleted,bool ignore_contenttype,
-          const StringArray&extra,
-          const StringArray&changelists
-            ) throw (ClientException)=0;
-
-    /**
-     * Same as other diff but extra options always set to empty list.
-     */
-    virtual QByteArray
-            diff_peg (const Path & tmpPath, const Path & path,const Path&relativeTo,
-                  const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
-                  Depth depth, bool ignoreAncestry,
-                  bool noDiffDeleted,bool ignore_contenttype) throw (ClientException)=0;
+            diff_peg(const DiffParameter&options) throw (ClientException)=0;
 
     /**
      * Produce diff output which describes the delta between
@@ -633,39 +437,12 @@ namespace svn
      * A ClientException will be thrown if either @a revision1 or
      * @a revision2 has an `unspecified' or unrecognized `kind'.
      *
-     * @param tmpPath prefix for a temporary directory needed by diff.
-     * Filenames will have ".tmp" and similar added to this prefix in
-     * order to ensure uniqueness.
-     * @param path1 first file or folder to diff.
-     * @param path2 second file or folder to diff.
-     * @param revision1 one of the revisions to check (path1).
-     * @param revision2 the other revision (path2).
-     * @param recurse whether the operation should be done recursively.
-     * @param ignoreAncestry whether the files will be checked for
-     * relatedness.
-     * @param noDiffDeleted if true, no diff output will be generated on deleted files.
-     * @param ignore_contenttype if true generate diff even the items are marked as binaries
-     * @param extra extra options for diff ("-b", "-w","--ignore-eol-style")
+     * @param options set of options required for diff
      * @return delta between the files
      * @exception ClientException
      */
     virtual QByteArray
-            diff (const Path & tmpPath, const Path & path1,const Path & path2,const Path&relativeTo,
-          const Revision & revision1, const Revision & revision2,
-          Depth depth, bool ignoreAncestry,
-          bool noDiffDeleted,bool ignore_contenttype,
-          const StringArray&extra,
-          const StringArray&changelists
-         ) throw (ClientException)=0;
-
-    /**
-     * Same as other diff but extra options and changelists always set to empty list.
-     */
-    virtual QByteArray
-            diff (const Path & tmpPath, const Path & path1,const Path & path2,const Path&relativeTo,
-                  const Revision & revision1, const Revision & revision2,
-                  Depth depth, bool ignoreAncestry,
-                  bool noDiffDeleted,bool ignore_contenttype) throw (ClientException)=0;
+            diff (const DiffParameter&options) throw (ClientException)=0;
 
     /**
      * lists entries in @a pathOrUrl no matter whether local or
@@ -729,42 +506,20 @@ namespace svn
      * set property in @a path no matter whether local or
      * repository
      *
-     * @param path
-     * @param revision
-     * @param propName
-     * @param propValue
-     * @param recurse
-     * @param skip_checks if true skip validity checks
-     * @return PropertiesList
+     * @param params svn::PropertiesParamter holding required values.
+     * Following is used:<br>
+     * <ul>
+     * <li> svn::PropertiesParameter::propertyName()
+     * <li> svn::PropertiesParameter::propertyValue()
+     * <li> svn::PropertiesParameter::depth()
+     * <li> svn::PropertiesParameter::skipCheck()
+     * <li> svn::PropertiesParameter::revision()
+     * <li> svn::PropertiesParameter::changeList()
+     * <li> svn::PropertiesParameter::revisionProperties()
+     * </ul>
      */
     virtual void
-    propset(const QString& propName,
-            const QString& propValue,
-            const Path &path,
-            Depth depth=DepthEmpty,
-            bool skip_checks=false,
-            const Revision&base_revision=Revision::UNDEFINED,
-            const StringArray&changelists=StringArray(),
-            const PropertiesMap&revProps=PropertiesMap()
-           ) = 0;
-
-    /**
-     * delete property in @a path no matter whether local or
-     * repository
-     *
-     * @param propName
-     * @param path
-     * @param revision
-     * @param recurse
-     */
-    virtual void
-    propdel(const QString& propName,
-            const Path &path,
-            Depth depth=DepthEmpty,
-            bool skip_check=false,
-            const Revision&base_revision=Revision::UNDEFINED,
-            const StringArray&changelists=StringArray())=0;
-
+    propset(const PropertiesParameter&params)=0;
 
     /**
      * lists revision properties in @a path no matter whether local or
@@ -796,19 +551,12 @@ namespace svn
      * set revision property in @a path no matter whether local or
      * repository
      *
-     * @param propName
-     * @param propValue
-     * @param path
-     * @param revision
-     * @param force
+     * @param params parameter to use
      * @return Revision
+     * @sa PropertiesParameter
      */
     virtual QLONG
-    revpropset(const QString& propName,
-               const QString& propValue,
-               const Path &path,
-               const Revision &revision,
-               bool force=false)=0;
+    revpropset(const PropertiesParameter&params)=0;
 
     /**
      * delete revision property in @a path no matter whether local or
@@ -823,8 +571,7 @@ namespace svn
     virtual QLONG
     revpropdel(const QString& propName,
                const Path &path,
-               const Revision &revision,
-               bool force=false) = 0;
+               const Revision &revision) = 0;
 
   /**
    * lock files in repository or working copy
