@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht
+ * (C) 2005-2007 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -50,7 +50,7 @@ namespace svn
         svn_revnum_t _revision,_copyfrom_rev,_cmt_rev;
         svn_node_kind_t _kind;
         svn_wc_schedule_t _schedule;
-        apr_time_t _text_time,_prop_time,_cmt_date;
+        DateTime _text_time,_prop_time,_cmt_date;
 
         /**
         * initializes the members
@@ -67,8 +67,17 @@ namespace svn
 
     void Entry_private::init_clean()
     {
-        _name = _url = _repos = _uuid = _copyfrom_url = _conflict_old = _conflict_new = _conflict_wrk
-            = _prejfile = _checksum = _cmt_author = QString::null;
+        _name.clear();
+        _url.clear();
+        _repos.clear();
+        _uuid.clear();
+        _copyfrom_url.clear();
+        _conflict_old.clear();
+        _conflict_new.clear();
+        _conflict_wrk.clear();
+        _prejfile.clear();
+        _checksum.clear();
+        _cmt_author.clear();
         _revision = _copyfrom_rev = _cmt_rev = -1;
         _kind = svn_node_unknown;
         _schedule = svn_wc_schedule_normal;
@@ -126,8 +135,9 @@ namespace svn
         } else {
             m_valid = false;
             m_Lock=LockEntry();
-            _name=
-            _url=_repos=_uuid=_copyfrom_url=_conflict_old=_conflict_new=_conflict_wrk=_prejfile=_checksum=_cmt_author= QString::null;
+            _name.clear();
+            _url.clear();_repos.clear();_uuid.clear();_copyfrom_url.clear();_conflict_old.clear();_conflict_new.clear();_conflict_wrk.clear();
+            _prejfile.clear();_checksum.clear();_cmt_author.clear();
             _copied=_deleted=_absent=_incomplete = false;
             _kind = svn_node_unknown;
             _schedule=svn_wc_schedule_normal;
@@ -259,13 +269,13 @@ namespace svn
     return m_Data->_cmt_author;
   }
 
-  const apr_time_t
+  const DateTime&
   Entry::cmtDate () const
   {
     return m_Data->_cmt_date;
   }
 
-  const svn_revnum_t
+  svn_revnum_t
   Entry::cmtRev () const
   {
     return m_Data->_cmt_rev;
@@ -276,13 +286,13 @@ namespace svn
     return m_Data->_checksum;
   }
 
-  const apr_time_t
+  const DateTime&
   Entry::propTime () const
   {
     return m_Data->_prop_time;
   }
 
-    const apr_time_t
+    const DateTime&
     Entry::textTime () const
     {
       return m_Data->_text_time;
@@ -308,7 +318,7 @@ namespace svn
     {
       return m_Data->_conflict_old;
     }
-    const svn_revnum_t
+    svn_revnum_t
     Entry::copyfromRev () const
     {
       return m_Data->_copyfrom_rev;
@@ -319,27 +329,27 @@ namespace svn
       return m_Data->_copyfrom_url;
     }
 
-    const bool
+    bool
     Entry::isAbsent () const
     {
       return m_Data->_absent;
     }
-    const bool
+    bool
     Entry::isDeleted () const
     {
       return m_Data->_deleted != 0;
     }
-    const bool
+    bool
     Entry::isCopied () const
     {
       return m_Data->_copied != 0;
     }
-    const svn_wc_schedule_t
+    svn_wc_schedule_t
     Entry::schedule () const
     {
       return m_Data->_schedule;
     }
-    const svn_node_kind_t
+    svn_node_kind_t
     Entry::kind () const
     {
       return m_Data->_kind;
@@ -359,7 +369,7 @@ namespace svn
     {
       return m_Data->_url;
     }
-    const svn_revnum_t
+    svn_revnum_t
     Entry::revision () const
     {
       return m_Data->_revision;
