@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht
+ * (C) 2005-2007 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -39,6 +39,10 @@ namespace svn
   apr_pool_t *
   Pool::pool_create (apr_pool_t * parent)
   {
+    if (!s_initialized) {
+        apr_pool_initialize();
+        s_initialized=true;
+    }
     return svn_pool_create (parent);
   }
 
