@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht
+ * (C) 2005-2007 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -45,6 +45,10 @@ namespace svn
   const svn_opt_revision_kind Revision::UNDEFINED = svn_opt_revision_unspecified;
   const svn_opt_revision_kind Revision::PREV = svn_opt_revision_previous;
 
+  const svn_opt_revision_kind Revision::DATE = svn_opt_revision_date;
+  const svn_opt_revision_kind Revision::NUMBER = Revision::START;
+
+
   Revision::Revision (const svn_opt_revision_t * revision)
   {
     init (revision);
@@ -52,8 +56,13 @@ namespace svn
 
   Revision::Revision (const svn_revnum_t revnum)
   {
-    m_revision.kind = svn_opt_revision_number;
-    m_revision.value.number = revnum;
+      if (revnum<0) {
+        m_revision.kind = svn_opt_revision_unspecified;
+        m_revision.value.number = 0;
+      } else {
+        m_revision.kind = svn_opt_revision_number;
+        m_revision.value.number = revnum;
+      }
   }
 
   Revision::Revision (const svn_opt_revision_kind kind)
@@ -205,19 +214,22 @@ namespace svn
     return &m_revision;
   }
 
-  const svn_revnum_t
+  svn_revnum_t
   Revision::revnum () const
   {
-    return m_revision.value.number;
+      if (m_revision.kind==svn_opt_revision_number) {
+          return m_revision.value.number;
+      }
+      return SVN_INVALID_REVNUM;
   }
 
-  const apr_time_t
+  apr_time_t
   Revision::date () const
   {
     return m_revision.value.date;
   }
 
-  const svn_opt_revision_kind
+  svn_opt_revision_kind
   Revision::kind () const
   {
     return m_revision.kind;
@@ -236,6 +248,14 @@ namespace svn
     return true;
   }
 
+  bool Revision::operator==(int value)const
+  {
+    if (m_revision.kind!=svn_opt_revision_number || value!=revnum()) {
+        return false;
+    }
+    return true;
+  }
+
   bool Revision::operator!=(const svn_opt_revision_kind t)const
   {
     return kind()!=t;
